# Angular Momentum, Torque & Central Forces # 

## Angular Momentum ##
A useful quantity, especially but no exclusive, when it comes to rotation is the angular momentum, defined as

```{math}
:label: eq:6.1
\vec{l} \equiv \vec{r} \times \vec{p}
```

Note that it is a cross product. Hence it is a vector itself. Further note that $\vec{r} \times \vec{p} \neq \vec{p} \times \vec{r}$. The order matters! First $\vec{r}$ then $\vec{p}$. If you do it the other way around, you unwillingly have introduced a minus sign that should not be there.<br>
Further note, that since $\vec{l} \equiv \vec{r} \times \vec{p}$, $\vec{l}$ is perpendicular to the plane formed by $\vec{r}$ and $\vec{p}$.

```{figure} images/AngularMomentum.jpg
---
name: fig:AngularMomentum.jpg
width: 250px
align: center
---
Angular momentum of a particle at a certain position with momentum.
```


### Torque & Analogy to N2 ###

Angular momentum obeys a variation of Newton's second law.

$$
\vec{l} = \vec{r} \times \vec{p} \Rightarrow 
$$

$$
\frac{d \vec{l}}{dt} = \frac{d (\vec{r} \times \vec{p} )}{dt}
=  \underbrace{\underbrace{\frac{d \vec{r}}{dt}}_{=\vec{v}} \times \vec{p} }_{=0 \text{ since } \vec{v} // \vec{p}}+ \vec{r} \times \underbrace{\frac{d\vec{p}}{dt}}_{\text{ N2: }= \vec{F} } 
=  \vec{r} \times \vec{F}
$$

Thus, we find a general law for the angular momentum:

```{math}
:label: eq:6.2

\frac{d \vec{l}}{dt} = \vec{r} \times \vec{F}
```

Again, note that the right hand side is a cross product, so the order does matter.

If we define the torque $\vec{\Gamma}$ as the force action on a particle about the origin

$$
\vec{\Gamma}\equiv \vec{r} \times \vec{F}
$$ 

then we can write down an equation similar to N2 $(\dot{\vec{p}}=\vec{F})$ but now for angular motion

$$
\dot{\vec{l}}=\vec{\Gamma}
$$

where the force is replaced by the torque and the linear momentum by the angular momentum.

NB: Note that the torque and angular moment change if we choose a different origin as this changes the value of $\vec{r}$.

````{admonition} Intermezzo: cross product 
:class: note

Here is some recap for the cross product. See also the [wiki](https://en.wikipedia.org/wiki/Cross_product) page.

$$
\vec{c} = \vec{a} \times \vec{b} \equiv \| a \| \|b\| \sin\theta \, \hat{n}
$$

Here $\theta$ is the angle between $\vec{a}$ and $\vec{b}$, and $\hat{n}$ is a unit vector normal to the plane spanned by $\vec{a},\vec{b}$ with direction given by the *right-hand rule*. 

```{figure} images/Right_hand_rule.png
---
name: fig:Right_hand_rule.png
width: 250px
align: center
---
Right hand rule for cross products. Adapted from [Wikimedia Commons](https://commons.wikimedia.org/wiki/File:Magnetic_field_element_%28Biot-Savart_Law%29_PRIME.svg), licensed under CC-BY-SA 4.0.
```


From the definition it is clear that $\| \vec{a}\times\vec{b}\|$ is the area of the parallelogram spanned by $\vec{a},\vec{b}$.


```{figure} images/area_cross.png
---
name: fig:area_cross.png
width: 250px
align: center
---
Area of cross products. From [Wikimedia Commons](https://commons.wikimedia.org/wiki/File:Cross_product_parallelogram.svg), public domain.
```

The cross product is bilinear, anti commutative $(\vec{a}\times\vec{b} = -(\vec{b}\times\vec{a}))$ and distributive over addition. 

The formula is for computation in an orthonormal basis is

$$
\left ( \begin{array}{c}a_1\\ a_2\\ a_3 \end{array}\right ) \times 
\left ( \begin{array}{c}b_1\\ b_2\\ b_3 \end{array}\right ) 
= \left ( \begin{array}{c}a_2b_3 - a_3b_2 \\ 
- (a_1b_3-a_3b_1) \\ a_1b_2-a_2b_1 \end{array}\right )
$$

How to *remember* this rule for the cross product in Cartesian or polar coordinates see [here](potential_energy#worked-example).
*****ik kan deze file niet vinden ****

The formula can be derived from the cross product for orthonormal basis vectors, e.g. $\hat{x},\hat{y},\hat{z}$

$$
\begin{array}{rcl}
\hat{x} \times \hat{y} &=& \hat {z}\\
\hat{y} \times \hat{z} &=& \hat {x}\\
\hat{z} \times \hat{x} &=& \hat {y}
\end{array}
$$

Notice the cyclic structure of the equations.

````

It is a common mistake to identify angular momentum with rotational motion. That is not correct. A particle that travels in a straight line will, in general also have a non-zero angular momentum. See {numref}`fig:AngularMomentumFreeParticle.jpg`. Here we look at a free particle: there are no forces working on it. So it travels in a straight line, with constant momentum. 

```{figure} images/AngularMomentumFreeParticle.jpg
---
name: fig:AngularMomentumFreeParticle.jpg
width: 250px
align: center
---
Angular momentum of a free particle.
```

However, the particle position does change over time. So: is its angular momentum constant or not? <br>
That is easy to find out. We could take 'N2' for angular momentum:

$$
\frac{d \vec{l}}{dt} = \vec{r} \times \underbrace{\vec{F}}_{\substack{=0 \\ \text{ free particle} }} = 0 \Rightarrow \vec{l} = \text{const}
$$

Clearly, the angular momentum of a free particle is constant. Moreover, the momentum of a free particle is also constant. But what about the position vector: isn't that changing over time and eventually becomes very, very long? Why does that not change $\vec{r} \times \vec{p}$? <br><br>
Take a look at {numref}`fig:ConstantAngularMomentum.jpg`. We have chosen the $xy$-plane such that both $\vec{r}$ and $\vec{p}$ are in it. Furthermore, we have taken it such that $\vec{p}$ is parallel to the $x$-axis.

```{figure} images/ConstantAngularMomentum.jpg
---
name: fig:ConstantAngularMomentum.jpg
width: 250px
align: center
---
Angular momentum of a free particle is constant.
```

At some point in time, the particle is at position $\vec{r}_1$. Its angular momentum is perpendicular to the $xy$-plane and has magnitude $|| \vec{r}_1 \times \vec{p} || = r_\perp p$.
Later in time it is at position $\vec{r}_2$. Still, its angular momentum is perpendicular to the $xy$-plane and has magnitude $|| \vec{r}_2 \times \vec{p} || = r_\perp p$, indeed identical to the earlier value. This shows that indeed the angular momentum of a free particle is constant.

## Examples ##
````{admonition} Example 6.1 Throwing a basketball
:class: important

As seen in class: one person throws a basketball to another via a bounce on the ground, the basketball starts to spin after hitting the ground although initially it did not.
	
```{figure} images/basketball.png
---
name: fig:basketball.png
width: 250px
align: center
---
Bouncing basketball
```

When the ball hits the ground a friction force is acting on the ball. This force will apply a torque on the ball. The friction is directed opposite to the direction of motion. The arm $\vec{r}$ from the center of the ball to where the force is acting, is downwards. Using the right-hand rule we find that the torque is pointing in the plane of the screen, and thus the rotation is clockwise (forwards spin).

The forwards momentum of the ball is reduced by the action of the force. The upwards components is just flipped by the bounce on the ground. Therefore the outgoing ball is bouncing up at a steeper angle than it is was incoming.

````

````{admonition} Example 6.2 Conservation of angular momentum & spinning wheel
:class: important

As seen in class. We have a student sitting on a chair that can rotate (swivel chair). The student is holding a bicycle wheel in horizontal position. 

	
```{figure} images/studentwheel.png
---
name: fig:studentwheel.png
width: 200px
align: center
---
Student with a rotating wheel
```

Once the student starts to spin the wheel while sitting on the chair, the student  will start to rotate in the opposite direction (with smaller angular velocity, lateron we will see why their speeds are different). Now you can understand that before the angular momentum of the student-wheel system is zero, and it has to remain so after he spins the wheel. To compensate the angular momentum pointing up (counter clockwise rotation), an angular momentum pointing down (clockwise rotation) of the same magnitude must occur.
````


## Exercises ## 

```{exercise-start}
:label: 61
```
A point particle (mass $m$) is initially located at position $P=(x_0,H,0)$. At $t = 0$, it is released from rest and falls in a force field of constant acceleration $\vec{a}=(0,a,0)$ that acts on the mass. 

Analyze what happens to the angular momentum of $m$.

```{exercise-end}
```

```{exercise-start}
:label: 62
```
The same question, but now the particle has an initial velocity $\vec{v} = (v_0 ,0,0)$.

```{exercise-end}
```

```{exercise-start}
:label: 63
```
Similar situation: can you find an example of a falling object for which the angular momentum stays constant? Ignore friction with the air. Why is the latter statement important?

```{exercise-end}
```



## Central Forces ##

We have looked at a specific class of forces: the conservative ones. Here we will inspect a second class, that is very useful to identify: the central forces.

A force is called a central force if:

$$
\vec{F} = |\vec{F}(\vec{r})| \hat{r}
$$

In words: a force is central of it points always into the direction of the origin or exactly in the opposite direction.
The reason to identify this class is in the consequences it has for the angular momentum.

Suppose, a particle of mass $m$ is subject to a central force. Then we can immediately infer that its angular momentum is a constant:

$$
\text{if } \vec{F} = |\vec{F}(\vec{r})| \hat{r} \text{ then } \frac{d\vec{l}}{dt} = \vec{r} \times \vec{F} =  |\vec{F}(\vec{r})| \vec{r} \times \hat{r} = 0
$$

where we have use that $\vec{r}$ and $\hat{r}$ are always parallel so their cross-product is zero.

The above is rather trivial, but has a very important consequence: a particle that moves with a constant angular momentum (vector!) must move in a plane. It can not get out of that plane. Thus its motion is at maximum a 2-dimensional problem. We can always use a coordinate system, such that the motion of the particle is confined to only two of the three coordinates, e.g. we can choose our $x,y$ plane such that the particle moves in it and thus always has $z(t) = 0$.

Why is this so? Why does the fact that the angular momentum vector is a constant immediately imply that the particle motion is in a plane? The argumentation goes as follows.
Imagine a particle that moves under the influence of a central force. At some point in time it will have position $\vec{r}_0$ and momentum $\vec{p}_0$. Neither of them is constant. We will assume that $\vec{r}_0$ and $\vec{p}_0$ are not parallel ( in general they will not be). Thus they define a plane. Due to the cross-product $\vec{l}_0 = \vec{r}_0 \times \vec{p}_0$ is perpendicular to this plane.  
A little time later, say $\Delta t$ later, both position and momentum will have changed. Since the force is central, the force is also in the plane defined by the initial position and momentum. Thus the change of momentum is in that plane as well: $\vec{p} (t + \Delta t) = \vec{p} (t) + \vec{F} \Delta t$. The right hand side is completely in our plane. And thus, the new momentum is also in the plane. But that means that the velocity is also in the same plane. An thus the new position $\vec{r} (t + \Delta t) = \vec{r}(t) + \frac{\vec{p}}{m} \Delta t$ must be in the same plane as well. We can repeat this argument for the next time and thus see, that both momentum and position can not get out of the plane.

## Central forces: conservative or not? ##
We can further restrict our class of central forces:

```{math}
:label: eq:6.3

\text{  if  } \vec{F}(\vec{r}) = f(r) \hat{r} \text{  then F is central and conservative} 
```

In the above, $|\vec{F}(\vec{r})| = f(r)$, 
that is: the magnitude of the force only depends on the distance from the origin not on the direction. Rephrased: the force is spherically symmetric. If that is the case, the force is automatically conservative and a potential does exist. Both the concept of central forces and potential energy play a pivotal role in understanding the motion of celestial bodies, like our earth revolving the sun. 
We will take a look at the planetary motion as an example of dealing with central forces. It is, however, also an example in its own right. Using his new theory, Newton was able to prove that the motion of the earth around the sun is an ellipsoidal one. It helped changing the way we viewed the world from geo-centric to helio-centric.

### Keppler's Laws ###
Before we embark at the problem of the earth moving under the influence of the sun's gravity, we will go back in time a little bit. 

````{admonition} Intermezzo: Tycho Brahe & Johannes Kepler
:class: note

We find ourselves back in the Late Renaissance, that is around 1550-1600 AD. In Europe, the first signs of the scientific revolution can be found. Copernicus proposed his heliocentric view of the solar system. Galilei used his telescope to study the planets and found further evidence for the heliocentric idea. In Denmark, Tycho Brahe (1546-1601) made astronomical observations with data of unprecedented precision. He did so without the telescope as the first records of telescopes date back to around 1608 AD. 

```{figure} images/BraheFam.png
---
name: fig:BraheFam.png
width: 400px
align: center
---
left:Tycho Brahe (1546-1601) - right: Sophia Brahe (1559-1643). From Wikimedia Commons 
([L](https://commons.wikimedia.org/wiki/File:Tycho_Brahe.JPG), [R](https://commons.wikimedia.org/wiki/File:Sophie_Brahe_portrait.jpg)), public domain.
```

Brahe initially studied law, but developed a keen interest in astronomy. He is heavily influenced by the solar eclipse of August 21st in 1560. The eclipse had been predicted via the theory of celestial motion at that time. However, the prediction was off by a day. This led Brahe to the conclusion that in order to advance celestial science, many more and much better observations were needed. He devoted much of his time in achieving this. One of his best assistants was his younger sister, Sophie. <br>
On November 11th 1572, Brahe observed a bright, new star in the constellation Cassiopeia (it consists of five bright stars forming a M or W). That was another event that made him decide to spend his days gathering astronomical data. The current believe in those days was still that everything beyond the Moon was eternal, never changing. So, this new star, that all in a sudden appeared, must be closer to the earth than the Moon itself. Brahe set out to measure its daily parallax against the five stars of Cassiopeia. But he didn't observe any parallax. Consequently, the new star's position had to be farther out than the Moon and the other planets that did show daily parallax. Moreover, Brahe kept measuring for months and still found no parallax. That meant that this new star was even further ut than the known planets that show now daily parallax but did so for periods of month. Brahe reached the conclusion that this new 'thing' thus could not be yet another planet, but that it was a star. Yet another nail to coffin of the Aristotle view. Brahe wrote a small book about it, called De Nova Stella (published in 1573). He uses the erm 'nova' for a new star. We see this back in our name for the phenomenon observed by Brahe: we call it a supernova. By now it is know that this new star, this supernova is some 7,500 light years away from us. Brahe was upset by those who denied the new findings. In his introduction of De Nova Stella he writes (given here in our modern words): "O coarse characters. O blind spectators of heaven". The work and the booklet made his name in Europe as a leading scientist and astronomer.

in the winter of 1577-1578 a comet, known as the Great Comet" appeared in the skies. It was observed by many all over the globe (from the Aztecs in the America's via European researchers to the Arabic world, India all the way to Japan). Brahe made thousands of recordings, some simultaneously done in Denmark (close to Copenhagen) and Prague. That way, Brahe could establish that the comet was much beyond the Moon.

At the end of his life, Brahe moved to Prague to become the official imperial astronomer under the protection of Rudolf II, the Holy Roman Emperor. In the later part of his life, Brahe had Johannes Kepler as his assistant. 

Kepler was 6 years old when the Great Comet appeared in the sky. He recorded in his writings that his mother had taken him to a high place to look at it. At the age of nine, he witnessed a lunar eclipse in which the Moon is in the Earth shadow, darkening it and turning quite red. As a child he suffered from smallpox making his vision weak and limited ability to use his hands. This made it difficult for him to make astronomical observations. It pushed him to mathematics. But there he was confronted with the Ptolemaic and the Copernican view on planetary motion. Kepler became a math professor at the Protestant Stiftsschüle in Graz. He wrote his ideas about the universe, following the thoughts of Copernicus in a book, that was read by Tycho Brahe. This brought him into contact with Brahe. In 1600 Kepler and his family moved to Prague as a consequence of political and religious oppression. He was appointed as assistant to Brahe and worked with Brahe on a new star catalogue and planetary tables. Brahe died unexpectedly on October 24th 1601. Two days later, Kepler was appointed as his successor. 

 ```{figure} images/Kepler.jpg
---
name: fig:Kepler.jpg
width: 220px
align: center
---
Johannes Kepler (1571-1630). From [Wikimedia Commons](https://commons.wikimedia.org/wiki/File:Portrait_Confused_With_Johannes_Kepler_1610.jpg), public domain.
```

 Kepler worked on a heliocentric version of the universe and in the period 1609-1619 published his first two laws. With these he changed from trying circular orbits to other closed ones, to arrive at an elliptical one for Mars. That one was in very good agreement with the Brahe date, much better than had been achieved before. Kepler realized that the other planets might also be in elliptical orbits. In comparison with Copernicus he stated: the planetary orbits are not circles with epi-circles. Instead it are ellipses. Secondly, The sun is not at the center of the orbit, but in one of the focal points of the ellipse. Thirdly, the speed of a planet is not a constant.

 Kepler's work was not immediately recognized. On the contrary, Galilei completely ignored it and many critized Kepler for introducing physics into astronomy.

````

Kepler has formulated three laws that describe features of the orbits of the planets around the sun.
<b>
<ol type="1">
<li>The orbit of a planet is an ellipse with the Sun at one of the two focal points.</li>
<li>A line segment joining a planet and the Sun sweeps out equal areas during equal intervals of time (Law of Equal Areas).

 ```{figure} images/Perkenwet.png
---
name: fig:Perkenwet.png
width: 350px
align: center
---
Kepler's 2nd Law of Equal Area.
```

</li>
<li>The square of a planet's orbital period is proportional to the cube of the length of the semi-major axis of its orbit.</li>
</ol>
</b>

<div align="center" style="font-size: 18px">

$$ \frac{T_A^2}{R_A^3} = \frac{T_B^2}{R_B^3}= const $$

</div>

It is important to realize, that Kepler came to his laws by -what we would now call- curve fitting. That is, he was looking for a generic description of the orbits of planets that would match the Brahe data. He abandoned the Copernicus idea of circles with epi-circles with the sun in the center of the orbit. Instead he arrived at ellipses with the sun out of the center, in the focal point of the ellipse. 

But, there was no scientific theory backing this up. It is purely 'data-fitting'. Nevertheless, it is a major step forward in the thinking about our universe and solar system. It radically changed from the idea that the universe is 'eternal', that is for ever the same and build up of circles and spheres: the mathematical objects with highest symmetry showing how perfect the creation of the universe is.

Kepler had formulated his laws by 1619 AD. It would take another 60 years before Isaac Newton showed that these laws are actually imbedded in his first principle approach: all that is needed is Newton's second law and his Gravitational Law.  We will derive in the next section Kepler's Laws from Newton's laws.

## Newton's theory and Kepler's Laws ##
In order to derive Kepler's laws from our Newtonian Mechanics, we will have to do some work. It starts with inspecting and classifying the force of gravity. Newton had formulated the Law of gravity: two objects of mass $m_1$ and $m_2$, respectively, exert a force on each other that is inversely proportional to the distance between the two masses and is always attractive. In a mathematical equation, we can make this more precise:

$$ \vec{F}_g = - G \frac{m_1 m_2}{r_{12}^2} \hat{r}_{12} $$

In the figure below, the situation is sketched. We have chosen the origin somewhere and denote te position of the sun and the planet by $\vec{r}_1$ and $\vec{r}_2$. Gravity works along the vector $\vec{r}_{12} = \vec{r}_2 - \vec{r}_1$. The corresponding unit vector is defined as $\hat{r}_{12} = \frac{\vec{r}_{12}}{r_{12}}$. 

 ```{figure} images/NewtonKeplerProblem.jpg
---
name: fig:NewtonKeplerProblem.jpg
width: 250px
align: center
---
The sun and a planet.
``` 

Newton realized that he could make a very good approximation. Given that the mass of the sun is much bigger than that of a planet, the acceleration of the sun due to the gravitational force of the planet on the sun is much less than the acceleration of the planet due to the sun's gravity. For this, we only need Newton's 3rd law:

$$ F_{g, sun \text{ }  on\text{ } planet} = - F_{g, planet \text{ }  on\text{ } sun} $$

Hence

$$ m_{sun} a_{sun} = -m_{planet} a_{planet} \rightarrow a_{sun} = \frac{m_{planet}}{m_{sun}} a_{planet} \ll a_{planet} $$

Newton concluded, that for all practical purposes, he could treat the sun as not moving. Next, he took the origin at the position of the sun. And from here on, we can ignore the sun and pretend that the planet feels a force given by

$$ \vec{F}(\vec{r}) = - G \frac{mM}{r^2}\hat{r} $$

with $M$ the mass of the sun and $m$ that of the planet. $r$ is now the distance from the planet to the origin and $\hat{r}$ the unit vector pointing from the origin to the planet.

<b>First observation</b> The force is central!<br>
<b> First conclusion</b> Then the angular momentum of the planet is conserved (is a constant during the motion of the planet) and the motion is in a plane, i.e. we deal with a 2-dimensional problem!

<b>Second Observation</b> The force is of the form $\vec{F}({\vec{r}}) = f(r) \hat{r}$<br>
<b> Second conclusion</b> Thus, we do know that a potential energy can be associated with it. It is a conservative force. This also implies that the mechanical energy of the planet, that is the sum of kinetic en potential energy, is a constant over time. In other words, there is no frictional force and the motion can continue forever. This seems to be inline with our observation of the universe: the time scales are so large that friction must be small.

In order to progress and derive e.g. the Area Law, we need to further develop our mathematical toolbox. We will do that in the next section, where we concentrate on polar coordinates $(r, \phi )$.

## Polar Coordinates ##
We do know that the motion of the planet is confined to a plane. Hence we can use a Cartesian coordinate system, $(x, y)$ or a polar (also called cylindrical) one with coordinates $(r, \phi )$.
These two are drawn in {numref}`fig:PolarCoordinates.jpg`. Note that coordinates only get their full meaning if we provide unit vectors. For Cartesian coordinates, we are so used to these, that we don't pay much attention to the unit vectors. But they are crucial. 

If our planet is at time $t$ at position $\vec{r}$, we can give the coordinates: the planet is at $(x,y)$. WHat we actually mean is to say: the planet is at position $\vec{r} = x \hat{x} + y\hat{y}$.

```{figure} images/PolarCoordinates.jpg
---
name: fig:PolarCoordinates.jpg
width: 550px
align: center
---
Polar and Cartesian coordinates and unit vectors.
``` 

However, we can equally well use Polar coordinates. With these we specify the distance $r$ from the origin and give the direction to move into via the angle $\phi$. We have to provide what $\phi = 0$ means and we do that by saying that that is the $x$-axis. But actually, that is not needed. All we need to do is describe one direction in the 2-dimensional world as $\phi = 0$. Nevertheless, it is convenient to call that direction the $x$-direction as we frequently switch between Polar and Cartesian coordinates. <br>

How would in our new Polar coordinate system that we are considering point P? <br>
First, we provide the coordinates: $(r, \phi )$. However, we need to represent the vector $\vec{r}$. In essence this is a recipe that tells us how to 'walk' to get from the origin to the point P. In Cartesian coordinates this reads as $\vec{r} = x\hat{x} + y\hat{y}$, which basically states: walk a distance $x$ in the direction of $\hat{x}$. Stop there and walk a distance $y$ in the $\hat{y}$ direction. In a Cartesian system this is trivial: $\hat{x}$ and $\hat{y}$ are always the same.<br>

However, in Polar coordinates, this is somewhat more complex. Here are 'walking recipe' is: to get to $\vec{r}$ walk a distance $r$ in the $\hat{r}$ direction. Simple, but strange: we seem to have no need for the second coordinate $\phi$. We simply have $\vec{r} = r \hat{r}$. But of course we need $\phi$. $r$ tells us how far we should walk, but it does not give the direction. That is provided by $\hat{r}$ and to know the direction of $\hat{r}$ we need to have $\phi$. 

This looks a bit puzzling at first sight. So, we better develop a formal set of relations between coordinates and unit vectors. This will allow us to 'navigate' between Polar and Cartesian coordinates and vice versa.

```{figure} images/PolarCartesian1.jpg
---
name: fig:PolarCartesian1.jpg
width: 250px
align: center
---
Polar and Cartesian coordinates of the same point.
``` 

From {numref}`fig:PolarCartesian1.jpg` we see that the coordinates are related to each other as:

$$x = r \cos \phi$$
$$y = r \sin \phi $$

or its inverse

$$r = \sqrt{x^2 + y^2}$$
$$\phi = \arctan \frac{y}{x}$$

The next step is to find relations that allow us to 'translate' the unit vector: $ ( \hat{r}, \hat{\phi } ) \leftrightarrow (\hat{x}, \hat{y} )$. We can do that using {numref}`fig:PolarCartesian2.jpg`.

 ```{figure} images/PolarCartesian2.jpg
---
name: fig:PolarCartesian2.jpg
width: 300px
align: center
---
Polar and Cartesian unit vectors.
``` 

From this figure we can infer the recipe how to 'go to' position $\hat{r}$. In Polar coordinates that is easy: walk one unit in the $\hat{r}$ direction. <br>
Cartesian we would do: walk $\cos \phi$ in the $\hat{x}$ direction and then $\sin \phi $ in the $\hat{y}$ direction. That we need to walk in the $x$-direction a distance of $\cos \phi$ is easy to understand: that is exactly the length of the projection of $\hat{r}$ on the $x$-axis. We can find confirmation in our rules for translating from $(r, \phi)$ to $(x, y)$ that we found above: take $r=1$ (as the unit vector has length 1) and thus $x = r \cos \phi = \cos \phi$.<br>

We can write the above in an equation rather than in words: $ \hat{r} = \cos \phi \hat{x} + \sin \phi \hat{y} $

We can also look at $\hat{\phi }$. From {numref}`fig:PolarCartesian2.jpg` we see that we need to walk a distance $\sin \phi$ in the negative $x$-direction and then $\cos \phi $ in the $y$-direction. Thus: $ \hat{\phi} = -\sin \phi \hat{x} + \cos \phi \hat{y} $. We will write the two relations once more below.

$$ \hat{r} = \cos \phi \text{  }\hat{x} + \sin \phi \text{  }\hat{y} $$
$$ \hat{\phi} = -\sin \phi \text{  }\hat{x} + \cos \phi \text{  }\hat{y} $$

If you progress further in physics and mathematics, you will learn that the above two equations signify a rotation over $\phi$. And that is indeed how we started: rotation the 'new, polar' coordinate system over an angle $\phi$ with respect to the 'old, Cartesian' one.
Why is this useful to know? Well, that makes it almost trivial to find the inverse relation, that is the one expression $\hat{x}$ and $\hat{y}$ in terms of $\hat{r}$ and $\hat{\phi}$. All we need to do is realize that the inverse is a rotation over $-\phi$: we have to rotate back. Thus, we see that the inverse is given by:

$$ \hat{x} = \cos \phi \text{  }\hat{r} - \sin \phi \text{  }\hat{\phi} $$
$$ \hat{y} = \sin \phi \text{  }\hat{r} + \cos \phi \text{  }\hat{\phi} $$

where we have used that $\cos (-\phi ) = \cos \phi$ and $\sin (-\phi ) = -\sin \phi$. If you don't see that immediately: don't worry, it is not difficult to find the inverse relation. It is show below:

$$ \hat{r} = \cos \phi \text{  }\hat{x} + \sin \phi \text{  }\hat{y} \Rightarrow \cos \phi \text{  } \hat{r} = \cos^2 \phi \text{  }\hat{x} + \cos \phi \sin \phi \text{  }\hat{y} $$
$$ \hat{\phi} = -\sin \phi \text{  }\hat{x} + \cos \phi \text{  }\hat{y} \Rightarrow \sin \phi \text{  }\hat{\phi} = -\sin^2 \phi \text{  }\hat{x} + \sin \phi \cos \phi \text{  }\hat{y}$$

Subtract the two, last version from each other and you get:

$$ \cos \phi \text{  } \hat{r} - \sin \phi \text{  }\hat{\phi} = \left ( \cos^2 \phi + \sin^2 \phi \right ) \text{  }\hat{x} $$

or rewritten

$$ \hat{x} = \cos \phi \text{  } \hat{r} - \sin \phi \text{  }\hat{\phi} $$

which is identical to the result we had above. 

Finding the expression for $\hat{y}$ in a similar way is left as an exercise.

### Velocity in Polar Coordinates ###

Now that we have established the relations between coordinates and unit vectors, we can go one step further. In mechanics, we deal with velocity, momentum, acceleration etc. How do these relate to our new coordinates and unit vectors. At first sight it seems trivial: $\vec{v} = \frac{d\vec{r}}{dt}$. So, we just need to do the differentiation in the new system. 

#### Naive and wrong way ####
Let's first be naive and copy what we have been doing in Cartesian coordinates:

$$\vec{v} \equiv \frac{d\vec{r}}{dt} = \frac{d}{dt} ( x\hat{x} + y\hat{y}) = \frac{dx}{dt}\hat{x} + \frac{dy}{dt}\hat{y} \equiv v_x \hat{x} + v_y \hat{y}$$

From which we get, that the coordinates of the velocity are: $(v_x, v_y )$.

So, we repeat the same but now using the Polar coordinates:

$$\vec{v} \equiv \frac{d\vec{r}}{dt} = \frac{d}{dt} ( r\hat{r}) = \frac{dr}{dt}\hat{r} \equiv v_r \hat{r} $$

However, it is immediately clear that this must be <b>wrong!!!</b> After all, this would imply that the velocity is always in the direction of $\hat{r}$ and that is simply not true. Take for instance the motion of a particle around a circle. Clearly, the distance from the origin is a constant for a circular motion. And thus $\frac{dr}{dt} = 0$. According to our above 'derivation', that would mean that the velocity is zero!

So, what went wrong?<br>
Actually, we might have been a bit hasty in deriving $\vec{v}$ in the Cartesian system. The expression we found is correct, but the reasoning behind it might have missed an important point. Let's go through the steps once more, but now with greater detail, not skipping steps. We start with the definition and the connection of the position to the Cartesian coordinates.

$$\vec{v} \equiv \frac{d\vec{r}}{dt} = \frac{d}{dt} ( x\hat{x} + y\hat{y}) $$

So far, so good. To proceed we have to use the product rule: $\frac{d (f \cdot g)}{dt} = f \frac{dg}{dt} + g \frac{df}{dt}$. Thus, we write

$$\vec{v} \equiv \frac{dx}{dt} \hat{x} + x \frac{d\hat{x}}{dt} + \frac{dy}{dt} \hat{y} + y \frac{d\hat{y}}{dt}$$

We note that both $\hat{x}$ and $\hat{y}$ are unit vectors that are constant, i.e. their size doesn't change (of course not: they have unit length) and their direction does not change (i.e. once we established the origin and both axis, the unit vectors are fixed and do not depend on time). We are so used to this, that we never think about $\frac{d\hat{x}}{dt}$. It is zero anyhow. And thus, we can leave the two derivative of the unit vectors out of the equation and find what we had: $\vec{v} = v_x \hat{x} + v_y \hat{y}$.

But for the Polar system, stuff is different! For different values of $\phi$ the unit vectors $\hat{r}$ and $\hat{\phi}$ point in different directions. Thus, although their size is the same - always their lengths equals 1- their direction might change if we follow a particle from point to point. But this implies that $\frac{d\hat{r}}{dt}$ and $\frac{d\hat{\phi}}{dt}$ are not zero. How do we find the correct answers? Let's start from the relation between the Polar unit vectors and the Cartesian ones.

$$ \hat{r} = \cos \phi \text{  }\hat{x} + \sin \phi \text{  }\hat{y} $$
$$ \hat{\phi} = -\sin \phi \text{  }\hat{x} + \cos \phi \text{  }\hat{y} $$

We take the time-derivative:

$$ \frac{d\hat{r}}{dt} = \frac{d\cos \phi \text{  }\hat{x}}{dt} + \frac{d\sin \phi \text{  }\hat{y}}{dt} \Rightarrow  $$
$$ \frac{d\hat{r}}{dt} = \frac{d\cos \phi}{dt} \hat{x} + \cos \phi \underbrace{\frac{d\hat{x}}{dt}}_{=0} + \frac{d\sin \phi }{dt} \hat{y} + \sin \phi \underbrace{\frac{d\hat{y}}{dt}}_{=0} \Rightarrow $$
$$
\begin{split}
 \frac{d\hat{r}}{dt} &= -\sin \phi \frac{d\phi }{dt} \hat{x} + \cos\phi \frac{d\phi }{dt} \hat{y} \\
&= \frac{d\phi }{dt} \left ( -\sin \phi  \hat{x} + \cos\phi  \hat{y} \right ) \\
& = \frac{d\phi }{dt}  \hat{\phi}
\end{split}
$$

Thus, we find that the change of the unit vector $\hat{r}$ with time is in the direction of $\hat{\phi}$. That of course makes sense: if $\frac{d\hat{r}}{dt}$ had a component in the $\hat{r}$ direction that would imply that its length would change. And that is of course not possible: it is a unit vector and will always have length 1.<br>
It is also understandable that de rate of change of $\hat{r}$ must scale with how quickly $\phi$ changes with time. After all, changing position affects $\hat{r}$ only if $\phi$ changes. And the quicker $\phi$ changes (that is, the larger $\frac{d\phi }{dt}$), the faster $\hat{r}$ will change (thus, the bigger $\frac{d\hat{r} }{dt}$).

Now we have $\frac{d\hat{r} }{dt}$, it is straightforward to copy the recipe to find $\frac{d\hat{\phi} }{dt}$. Try to derive it yourself. You should find

$$
 \frac{d\hat{\phi}}{dt} = -\frac{d\phi }{dt}  \hat{r}
$$

Now, we can reconsider the velocity vector in Polar coordinates:

$$
\begin{split}
\vec{v} &= \frac{d\vec{r}}{dt} = \frac{d(r\hat{r})}{dt} \\
&= \frac{dr}{dt}\hat{r} + r\frac{d\hat{r}}{dt} \\
&= \frac{dr}{dt}\hat{r} + r\frac{d\phi}{dt}\hat{\phi}\\
&= v_r \hat{r} + v_\phi \hat{\phi}
\end{split}
$$

In summary, we have found for the Polar coordinate system:

```{admonition} Coordinate Transformation 
:class: note

$$x = r \cos \phi$$
$$y = r \sin \phi $$

and its inverse

$$r = \sqrt{x^2 + y^2}$$
$$\phi = \arctan \frac{y}{x}$$

<h3> Unit Vectors </h3>

$$ \hat{r} = \cos \phi \text{  }\hat{x} + \sin \phi \text{  }\hat{y} $$
$$ \hat{\phi} = -\sin \phi \text{  }\hat{x} + \cos \phi \text{  }\hat{y} $$

and its inverse

$$ \hat{x} = \cos \phi \text{  }\hat{r} - \sin \phi \text{  }\hat{\phi} $$
$$ \hat{y} = \sin \phi \text{  }\hat{r} + \cos \phi \text{  }\hat{\phi} $$

<h3> Position Vector </h3>

$$\vec{r} = x \hat{x} + y\hat{y} = r \hat{r} $$

<h3> Velocity Vector </h3>

$$ \vec{v} = \underbrace{\frac{dx}{dt}}_{=v_x} \hat{x} + \underbrace{\frac{dy}{dt}}_{v_y} \hat{y} = \underbrace{\frac{dr}{dt}}_{v_r} \hat{r} + \underbrace{r\frac{d\phi}{dt}}_{v_\phi} \hat{\phi} $$

Thus, we can represent the position by $(x,y)$ or $(r, \phi )$ and the velocity by $(v_x, v_y ) = \left ( \frac{dx}{dt}, \frac{dy}{dt} \right )$ or by $(v_r, v_\phi ) = \left ( \frac{dr}{dt}, r\frac{d\phi}{dt} \right )$.

```

## Newton's theory and Kepler's Laws - part 2 ##
We have:
<ol>
<li> The sun is replaced by a force field originating at the origin. This force field is a central force. 
<ul>
    <li>Thus, the angular momentum is conserved.</li>
    <li> The orbit is in a plane: we deal with a 2-dimensional problem.</li>
</ul></li>
<li> The force is conserved: a potential exists.</li>
</ol>

Based on these, we will derive Kepler's laws only using Newtonian Mechanics.

The first step is to calculate the angular momentum. Why? We know it is a constant as the force is central. Thus, during the motion of a planet around the sun, the angular momentum stays constant, giving a strong relation between the position and the momentum of the planet.

Angular momentum, $\vec{l} \equiv \vec{r} \times \vec{p}$, can be represented in Cartesian as well as Polar coordinates. It is useful to use the latter. We will take our coordinate system such that the orbit of the planet is in the $z=0$ plane.

$$ \begin{split}
\vec{l} &\equiv \vec{r} \times \vec{p} \\
&= r\hat{r} \times (mv_r \hat{r} + mv_\phi \hat{\phi}) \\
&= mrv_\phi \hat{z} \\
&= mr^2 \dot{\phi} \hat{z} = const
\end{split}
$$

Thus, we see that $r$, that is the radial coordinate of the position of the planet and the angular velocity of the planet $\dot{\phi}$ are related. The direction of the angular momentum is in the $z$-direction and it will stay that way as the <em>vector</em> angular momentum is a constant.

The magnitude of the angular momentum, $l$, is constant too:

$$l = mr^2 \dot{\phi} \Leftrightarrow \dot{\phi} = \frac{l}{mr^2} $$

With this, we are surprisingly close to Kepler's Equal Area Law. The argument goes as follows. 

```{figure} images/PerkenWetFig.png
---
name: fig:PerkenWetFig.png
width: 150px
align: center
---
Trajectory of a planet.
``` 

Consider a planet moving through the $(r, \phi )$-plane. It goes from its position $\vec{r}$ at time $t$ to $\vec{r} + d\vec{r}$ at $t+dt$, see {numref}`fig:PerkenWetFig.png`. From the figure we get, that the area between the trajectory and the two positions is close to a triangular area. The smaller $d\phi $ the better a triangle is to describe the area. 

The area of the triangle is $dA = \frac{1}{2} r \cdot rd\phi = \frac{1}{2}r^2 d\phi$.

This area is 'swept' in a time $dt$. Thus the rate at which the planet sweeps through the area is

$$ \frac{dA}{dt} = \frac{1}{2}r^2 \frac{\phi}{dt} = \frac{1}{2}r^2 \dot{\phi}$$

Now, we will eliminate $\dot{\phi}$ using the angular momentum:

$$\frac{dA}{dt} = \frac{l}{2m} $$

However, the above expression is constant, as both $l$ and $m$ are constant. In other words: in equal times, say $\Delta t$, equal parts are swept: $\frac{dA}{dt} = \frac{l}{2m} \rightarrow A(t) = A_0 + \frac{l}{2m}t \rightarrow \Delta A = \frac{l}{m} \Delta t$, which is a mathematical description of Kepler's Equal Area Law!
<br><br>

### Planets travel in ellipses ###
To find the other two laws, we will have to work harder. We will start by an energy consideration. We know that our gravitational force is both central and conservative. Thus the sum of kinetic and potential energy is constant. Again, we will use Polar coordinates.

The kinetic energy is given by

$$ \begin{split}
E_{kin} &= \frac{1}{2}mv^2 = \frac{1}{2} m (v_r^2 + v_\phi ^2) \\
&= \frac{1}{2} (\dot{r}^2 + r^2 \dot{\phi}^2)
\end{split}
$$

The potential energy is found by solving $V(r) = -\int_{r_{ref}}^r \vec{F}_g \cdot d\vec{r} $. We can plug in $\vec{F}_g = - G \frac{mM}{r^2} \hat{r}$. Thus only the radial coordinate is of importance in the inner product in the integral. Furthermore, we will use as reference boundary: $\infty$. Thus, the potential energy is:

$$ \begin{split}
V(r) &= -\int_{r_{ref}}^r \vec{F}_g \cdot d\vec{r} \\
&= GmM \int_\infty^r \frac{dr}{r^2} \\
& = -G\frac{mM}{r} 
\end{split} $$

Thus, energy conservation leads to:

$$ \frac{1}{2} (\dot{r}^2 + r^2 \dot{\phi}^2) - -G\frac{mM}{r} = E_0 = const $$

As expected: we have an equation with two unknowns $(r(t), \phi (t))$. Once we solved the problem, we will thus have the coordinates of the planet's trajectory as a function of time. However, we will not do that. Reason: it is complicated and we don't need it! What we need is to find what kind of figure the trajectory is. And for that it is quite ok to find $r$ as function of $\phi$, that is, we will try to find $r(\phi )$ and see whether or not that describes an ellipse.

Our first step is to bring the number of unknowns in the energy equation down from two to one. For that, we use again that the angular momentum is constant. This allows us to eliminate $\dot{\phi}$:

$$ \frac{1}{2} \dot{r}^2 + \frac{l^2}{2mr^2} - -G\frac{mM}{r} = E_0 = const $$

We can interpret this in a different way: the second term originates from kinetic energy, but now looks like a potential energy. And that is exactly what we are going to do: treat it as a potential energy. 

Now we can first inspect the global features of our energy equation. Notice that the gravity potential energy is an increasing function of the distance from the planet to the sun (located and fixed in the origin). This shows that the underlying force attractive is. The new part, coming from angular momentum, on the other hand is a decreasing function of distance. Thus, the related force is repelling. 

We can make a drawing of the energy. See {numref}`fig:KeplerEnergy.png`.

```{figure} images/KeplerEnergy.png
---
name: fig:KeplerEnergy.png
width: 450px
align: center
---
Potential energy of a planet.
``` 

The blue line is the potential energy of gravity. The red one stems from the kinetic energy associated with the angular velocity. The black line is the sum of the two, a kind of effective potential:

$$ U_{eff} = \frac{l^2}{2mr^2} - -G\frac{mM}{r} $$

We see, that the energy can not be just any value: the kinetic energy of our quasi-one-dimensional particle ($\frac{1}{2}m\dot{r}^2$) can not be negative and the total potential energy has, according to {numref}`fig:KeplerEnergy.png` a clear minimum. The total energy can not be below this minimum. On the other hand: there is no maximum.<br><br>

<b>Case 1: </b>$U_{eff} = minimal$

Suppose, we would prepare the system such that its total energy was equal to the minimum of the black line, i.e. of the total potential energy. Then, of course, via the arguments we have given above this is only possible if the kinetic energy is zero. 

$$ E_{kin} + U_{eff}(r) = U_{eff, min} \Rightarrow E_{kin} = 0 $$

This implies that $\dot{r} = 0$:

$$E_{kin} = \frac{1}{2} m \dot{r}^2 = 0 \rightarrow \dot{r} = 0 $$

At first glance, this seems strange: $\dot{r} = 0$ suggests that our particle doesn't move, it has velocity zero. That would be strange: after all we are dealing here with a planet that is attracted via gravity towards the sun. How can it possible have zero velocity?

We are about to make a mistake: $\dot{r} = 0$ doesn't mean that the velocity is zero. It means that $r(t) = const$. The planet still has an angular velocity: $\dot{\phi} = \frac{l}{2mr^2} = const$ as in this particular case $r = const$. 

Thus, we conclude that for this case the planet moves at a constant distance around the sun at a constant angular velocity, that is: it moves in a circle at constant angular velocity.

<b>Case 2: </b>$U_{eff, min} < E_{tot} < 0$

Next, we consider a case where the total energy of the planet has a value between the minimum of the curve of the effective potential and 0. Call the value of the energy $E_2$.

From {numref}`fig:KeplerEnergy2.png` we see that the planet will now be confined in an area where the effective potential is either equal to or smaller than this particular value $E_2$ 

 ```{figure} images/KeplerEnergy2.png
---
name: fig:KeplerEnergy2.png
width: 550px
align: center
---
Total energy between 0 and minimum of effective potential.
```

Thus,the trajectory is confined between $r=r_a$ and $r=r_b$. At both these end points, the planet will have zero radial velocity: $\dot{r}_a = \dot{r}_b = 0$. However, as before, the planet will still have angular momentum and thus still have a non-zero angular velocity. 
The planet will travel in the $(r,\phi )$-plane between $r=r_a$ and $r=r_b$. How? We don't know yet. 

N.B. Do realize, that the angular velocity is for this case not a constant. We already have established that it is linked to the angular momentum (which is a constant) and the distance to the origin:

$$\dot{\phi} = \frac{l}{2mr^2} $$

Thus, if the planet is closer to $r_a$ it moves faster than close to $r_b$. But it can not escape from $r_a < r(t) < r_b$.

<b>Case 3: </b>$E_{tot} > 0$

Finally, we take the case that the total energy of the planet is positive, say a value of $E_3$ in {numref}`fig:KeplerEnergy3.png`. Now we see that the planet can approach the sun, but not closer than a distance $r=r_c$. The planet is attracted to the sun, but after reaching the closest distance $r=r_c$ it will move away and eventually reach infinity. Again note: at $r=r_c$, the planet does have a non-zero velocity.

 ```{figure} images/KeplerEnergy3.png
---
name: fig:KeplerEnergy3.png
width: 450px
align: center
---
Total energy larger than 0.
```

#### Ellipsoidal orbits ####
We are left with the task of showing that planets 'circle' the sun in an ellipse. From the above, we now know that this must mean that the total energy is smaller than zero: $E<0$.

Below is the math of showing that the orbit is indeed an ellipse.

We are going to try and find $r(\phi )$, rather than $r(t)$ and $\phi (t)$. Our starting point is

$$\frac{1}{2}m \dot{r}^2 + \frac{l}{2mr^2} - G\frac{mM}{r} = E =const $$

Notice that this a differential equation is for $r(t)$. Its solution is constrained by:

$$ l = mr^2 \dot{\phi} =const $$

It seems that this turns our problem back into a 2-dimensional one where we have to try to find $r(t)$ and $\phi (t)$. But we will not do so, as mentioned. Instead we will use the second equation to eliminate time derivatives from our problem.

First, we notice that in the energy equation we divide by $r$ and $r^2$. It will be easier to replace $r$ by $u \equiv \frac{1}{r}$

Next, we use that $r = r(\phi) = r(\phi (t))$. Thus for the time derivative of $r$ we can write:

$$ \dot{r} =\frac{dr}{dt} = \frac{dr}{d\phi}\frac{d\phi}{dt} $$

In $\frac{dr}{d\phi}$ we replace $r$ by $\frac{1}{u}$:

$$ \frac{dr}{d\phi } = -\frac{1}{u^2} \frac{du}{d \phi} $$

Put the last two equation together:

$$\dot{r} = -\frac{1}{u^2} \frac{du}{d \phi} \frac{d\phi}{dt} = -r^2 \dot{\phi} \frac{du}{d \phi} $$

We recognize the angular momentum in the third term:

$$\dot{r} =  -\frac{l}{m} \frac{du}{d \phi} $$

Substitute this in the energy equation and we get:

$$\frac{l^2}{2m} \left ( \frac{du}{d \phi} \right )^2 + \frac{l}{2m} u^2 - GmMu = E =const $$

You may not recognize this equation, but it has some similarities with $\left ( \frac{df}{dx} \right )^2 + f^2 = 1$ which has a solution $\sin$ and $\cos$. To arrive at such an equation, we need to combine the second and third term (the two potentials) into one that is quadratic in the unknown function. This can be done in the following way:

$$\left ( \frac{du}{d \phi} \right )^2 + u^2 - \frac{2gMm^2}{l^2} u = \frac{2mE}{l^2}$$

Introduce the short-hand notation:

$$ \frac{1}{\alpha} \equiv \frac{2GMm^2}{l^2} $$

and we can write for the energy equation:

$$\alpha \left ( \frac{du}{d \phi} \right )^2 + \alpha u^2 - 2u = \frac{2E}{GMm}$$

The second and the third term can be written ar:

$$\alpha u^2 - 2u = \frac{1}{\alpha} \left ( \alpha u - 1 \right )^2 - \frac{1}{\alpha}$$

Next, we introduce a new variable:

$$ z = \alpha u - 1$$

Obviously $\frac{du}{d\phi } = \frac{1}{\alpha} \frac{dz}{d\phi }$. And we can, finally, cast our energy equation in a familiar form:

$$ \left ( \frac{dz}{d \phi} \right )^2 + z^2 = \frac{2E\alpha }{GMm} + 1 $$

We place $\alpha$ back and get:

$$ \left ( \frac{dz}{d \phi} \right )^2 + z^2 = \frac{2El^2 }{(GMm)^2m} + 1 \equiv e^2 $$

So, finally, we have our energy equation in a form that is easy to solve:

$$ z(\phi ) = e \cos (\phi - \phi_0 )$$

with $\phi_0$ an integration constant or re-phrased, the starting angle at the time we start to follow the planet on its trajectory.

We will now replace $z$ by $u$ and $u$ by $r$. That gives us the radial coordinate as function of the angle $\phi$:

$$ r(\phi ) = \frac{\alpha}{e \cos (\phi - \phi_0 ) + 1}$$

with 

$$ e = \sqrt{1 + \frac{2El^2}{(GMm)^2m}} $$

and 

$$ \alpha \equiv \frac{l^2}{2GMm^2} $$

This type of curve in the $(r, \phi )$ plane is know as the conic sections. That is, they can be found by intersecting a cone with a plane.


 ```{figure} images/conic_sections_small.gif
---
name: fig:conic_sections_small.gif
width: 550px
align: center
---
Conic sections; from [MathGifs](https://mathgifs.blogspot.com/2014/09/the-conic-sections.html).
``` 

%<a title="Lucas Vieira, Public domain, via Wikimedia Commons" href="https://commons.wikimedia.org/wiki/File:Blue_cut-cone.gif"><img width="256" alt="Blue cut-cone" src="https://upload.wikimedia.org/wikipedia/commons/9/94/Blue_cut-cone.gif?20061004024212"></a>



Note that in the definition of $e$, the total energy of the system plays a role. This energy can be negative (see {numref}`fig:KeplerEnergy.png`). The minimum value of the effective potential energy is easily computed. It is $U_{eff, min} = -\frac{1}{2} \frac{(GmM)^2m}{l^2}$ and is realized when the planet is at a distance $r = \frac{l^2}{GMm^2}$. For this case we have $e = 0$. This means that $r(\phi ) = \alpha $, thus a constant: the planet is moving in a circle around the sun, as we already argued above.

For $0 \leq e < 1 $ the orbit is an ellipse as Kepler already had postulated (for these values of $e$ the orbit is a closed one).

For $e=1$, the orbit is a parabola: the object will eventually move to infinity where it has exactly zero radial velocity.

Finally, for $e > 1$ the trajectory is a hyperbola with the planet again moving to infinity.

We can change from Polar coordinates to Cartesian. This will give the following expression for the orbit in case of an ellipse:

$$ \frac{(x+ea)^2}{a^2} + \frac{y^2}{b^2} = 1 $$

<br>

 ```{figure} images/KeplerEllips.png
---
name: fig:KeplerEllips.png
width: 350px
align: center
---
Ellips in Cartesian coordinates.
```

This is an ellipse with semi major and minor-axis $a$ and $b$, respectively. The center of the ellipse is located at $(-ea,0)$. Note that the sun is in the origin and that seen from the center of the ellipse, the origin is at one of the focal points of the ellipse. Consequently, the orbit is not symmetric as viewed from the sun. We notice this on earth: the summer and winter (when the sun is closest respectively furthest from the sun) are not symmetric, even if we take the tilted axis of the earth into account.

The half and short long axis are given by:

$$a = \frac{\alpha}{1-e^2} = \frac{GMm}{2|E|}$$
$$b = a\alpha = \frac{l^2}{2m|E|}$$

<b>Conclusion: according to Newton's laws of mechanics, combined with the Gravitation force proposed by Newton, planets must move in ellipses around their star.</b> 

This holds for our solar system, but for any other star with planets as well. Research has shown that there are hundreds of solar systems out in the universe with thousands of planets moving around their star. See e.g. https://exoplanets.nasa.gov/ 
<br><br>


### Kepler 3 ###
We are left with proving Kepler's third law:

$$ \frac{T_A^2}{R_A^3} = \frac{T_B^2}{R_B^3}= const $$

Now that we know the orbit, this is not difficult. We concentrate on the motion during one lapse (one 'year'). From Keppler's 1<sup>st</sup> law we know that the area a planet sweeps out of its ellipse is given by

$$ A(t) = \frac{l}{2m}t + C $$

where $C$ is an integration constant. Furthermore, this way of writing makes that the area swept keeps increasing: after one round along the ellipse, we simply keep counting.

However, we can easily back out what happens after exactly one round, or one 'year'. The total area swept is then, of course, the area of the ellipse itself, that is: in one year (time $T$) the area swept is $\pi a b$. Hence we conclude:

$$ A(T) = \pi a b \Rightarrow \pi ab = \frac{l}{2m}T $$

If we put back what we found for $a$ and $b$, we get

$$ \frac{T^2}{a^3} = \frac{4\pi^2}{GM}$$

Thus, indeed Kepler was right. Moreover, we note that the constant is only depending on the mass of the sun. The same law will hold for other solar systems, but with a different constant.

In {numref}`fig:FigureKepler3.png` Kepler's third law is shown for our solar system. The red data points are based on the measured 'year' of each planet and the distance to the sun. The blue line is the prediction from Newton's theory.

```{figure} images/FigureKepler3.png
---
name: fig:FigureKepler3.png
width: 450px
align: center
---
Kepler 3 for our solar system.
```

````{admonition} Haley's comet 
:class: note

The planets aren't the only objects that move around the sun. Several icy, rocky smaller objects are trapped in a closed orbit around the sun. These objects, comets from the Greek word for 'long-haired star', are left-overs from when our solar system was formed, some  4.6 billion years ago. There are many comets in our solar system. More than 4500 have been identified, but there are probably much more. Usually the orbit of a comet, if its is a closed one, has a high eccentricity (i.e. close to 1). Moreover, their orbital period may be very long.

One of the best visible comets is Haley's comet. However, its orbital period is about 75 years. It last appeared in the inner parts of the Solar System in 1986. So, you will have to wait until mid-2061 to see it again.


```{figure} images/Halley's_Comet_animation.gif
---
name: fig:Halley's_Comet_animation.gif
width: 400px
align: center
---
Trajectory of Haley's comet. From [Wikimedia Commons](https://commons.wikimedia.org/wiki/File:Halley%27s_Comet_animation.gif), licensed under CC-BY 4.0.
```

````

## The sun as a point mass ##

In the above we assumed that the sun of mass $M_{sun}=2\cdot 10^{30}$ kg with a radius of $R_{sun}= 7\cdot 10^6$ km can be viewed as a point mass with the same mass for using Newton's law of gravity. We just plucked in the mass, we did not bother about the mass distribution at all!

In fact this is allowed as long as the mass distribution is spherically symmetric as you will see below. We start from the gravitational (1D) potential $V(x)=-G\frac{mm'}{x}$. For this potential holds $\nabla V = -\vec{F}_g=-G \frac{mm'}{x^2}\hat{x}$. The derivation has a number of clever tricks to work out the integral and optimal choice of coordinates.

Moreover, the actual mass distribution of the sun does not matter, even if it would be non spherical. That is because the size of the sun is small compared to the distance to the earth. Any differences in the gravitational force are absolutely tiny because that distance is so large (radius of the sun is $7\cdot 10^5$ km and the distance to the earth is $>10^8$ km.

We consider a massive spherical shell with surface mass density $\sigma$ (per unit area). Now compute the potential at some point $P$ on the surface with coordinates $(r,\phi)$ with some distance $x$ from the center of the shell and distance $w$ from a point on the surface. 


```{figure} images/sunpoint.png
---
name: fig:sunpoint.png
width: 450px
align: center
---

```
The potential is given as

$$
dV = -G\frac{m\sigma dA}{w} = -2\pi G \frac{m\sigma r^2\sin\theta \,d\theta}{w}
$$

with $m'=\sigma dA$, $dA=2\pi r \sin\theta\, rd\theta$ the revolution of the line element around $2\pi$. If we additionally use the relation $w^2=x^2+r^2-2xr\cos\theta$ to allow integration over $w$ rather than $\theta$, the differential is $wdw = xr \sin\theta\,d\theta$. This is very similar to what we have in the nominator above, thus

$$
dV = -2\pi G \frac{m\sigma rdw}{x} 
$$

If the point $P$ is outside the shell, the angles varies $\theta \in [0,\pi]$ or $w\in[x-r,x+r]$ and we can calculate the potential

$$
V(x) = -2\pi G \frac{m\sigma r}{x}\int_{x-r}^{x+r} dw = -\frac{4\pi Gm\sigma r^2}{x} 
$$

With the mass of the shell $M=4\pi r^2\sigma$ we finally obtain

$$
V(x) = -\frac{GMm}{x} 
$$

We see indeed that the mass distribution integrates out and we can deal with a point mass concentrated at the center of the shell. Hurray!

### Gravity inside a shell

The gravitational force *inside* a shell (hollow sphere) is *zero* - always - independent where inside of the shell you are. This result will pop up again in electrostatics where the electric force inside a charged spherical surface is zero. As the form of the gravitational and electric force are similar in their functional form $\vec{F}(\vec{r})\propto r^{-2}\hat{r}$ this is not surprising.
This a bit counter intuitive result is easy to see, if you apply <a href="https://en.wikipedia.org/wiki/Gauss%27s_law_for_gravity">Gauss theorem</a>. 

$$
\int_S \vec{f}\cdot dA = \int_V \nabla 
\cdot \vec{f}\, dV =4\pi G M \quad (\text{or } \frac{q_1}{\epsilon_0})
$$

where $\vec{f}$ is the gravitational $\vec{f}=\frac{\vec{F}_g}{m}=-GM\frac{\hat{r}}{r^2}$ or electric field $\vec{f}=\frac{\vec{F}_E}{q_0}= \frac{1}{4\pi\epsilon_0}\frac{q_1 \hat{r}}{r^2}$. The mass $M$ (or charges $q$) is the sum of the mass *inside* the volume that the surface $S$ encloses. If the surface does not enclose any mass (or charge), as is the case inside the shell, then the flux ($\vec{f}\cdot dA$) and field must be zero!

You can also integrate out the force as <a href="http://hyperphysics.phy-astr.gsu.edu/hbase/Mechanics/sphshell2.html">done here</a> but that is quite some work.

## Speed of the planets & dark matter

Starting from Kepler 3, we can compute the orbital speed of a planet around the sun


$$ \begin{split}
T^2 &= \frac{4\pi^2}{GM}a^3\\
\omega^2 &= \frac{GM}{a^3}, \quad T=\frac{2\pi}{\omega}, \omega=\frac{v}{r},  a \approx r \\
\Rightarrow v &= \sqrt{\frac{GM}{r}}
\end{split} $$

Indeed if we measure the speed of the planets in the solar system this prediction holds, the velocity drops with the distance from the sun as $\propto r^{-1/2}$ (see figure). As $M$ we use the mass of the sun here.

```{figure} images/orbitalspeed.jpg
---
name: fig:orbitalspeed.png
width: 450px
align: center
---
From [LibreTexts Physics](https://phys.libretexts.org/Bookshelves/Astronomy__Cosmology/Big_Ideas_in_Cosmology_%28Coble_et_al.%29/08%3A_Dark_Matter/8.02%3A_Velocities_Mass_and_Gravity-_the_Solar_System), licensed under CC BY-NC-SA 4.0.
```

The distance is measured in <a href="https://en.wikipedia.org/wiki/Astronomical_unit">Astronomical Units [AU]</a>, the distance from the earth to the sun (about 8.3 light minutes). Note that the earth is moving with an unbelievable 30 km/s, that is $10^5$ km/h! Do you notice any of that? We will use this motion later with the Michelson-Morley experiment.

If we plot the same speed versus distance curve not for the planets in our solar system, but for stars orbiting the center of our galaxy, the milky way, then the picture looks very different. The far away stars orbit at a much higher speed than expected and the form of the found curve does not match $\propto r^{-1/2}$. 

```{figure} images/orbitmilkyway.png
---
name: fig:orbitmilkyway.png
width: 450px
align: center
---
From [Wikimedia Commons](https://commons.wikimedia.org/wiki/File:Rotation_curve_of_the_Milky_Way.png), licensed under CC-SA 3.0.
```

This mismatch is not understood to this day! The mass $M$ here is calculated from the visible stars and the supermassive black holes at the center of the galaxy. But even if the mass is calculated wrongly, the shape of the dependency does not match. It turns out, this mismatch is observed in all galaxies! Apparently the law of gravity does not hold for large distances *or* there must be extra mass that increases the speed that we do not see. This mismatch has lead to the postulation of <a href="https://en.wikipedia.org/wiki/Dark_matter"><em>dark matter</em></a> and an <a href="https://en.wikipedia.org/wiki/Alternatives_to_general_relativity"><em>alternative formulation</em></a> for the laws of gravity. This is the most disturbing problem in physics today; second is probably the interpretation of <a href="https://en.wikipedia.org/wiki/Measurement_in_quantum_mechanics">measurement</a> in quantum mechanics (collapse of the wave function/Kopenhagen interpretation of Quantum Mechanics; multiverse theories). 

The majority of all matter in the universe is believed to be *dark*. And we have no clue what it could be! Most scientist even think it must be <a href="https://en.wikipedia.org/wiki/Baryon">non-baryonic</a>, that is, other stuff than our well-known protons or neutrons. It remains most confusing.

The usual distance unit for distances in astronomy outside the solar system is not light years (ly), but <a href="https://en.wikipedia.org/wiki/Parsec">parsec</a> [pc], or kpc, or Mpc. One parsec is about 3.3 ly (or $10^{13}$ km). Note: stars visible to the eye are typically not more than a few hundred parsec away. The milkyway is perfectly visible to the naked eye as a band/stripe of "milk" sprayed over the night sky. But you cannot see it anywhere close to Delft, there is much too much light from cities and greenhouses. Go to Scandinavia in the winter ("wintergatan") or any place remote where there are little people. The reason you see a "band" in the night sky, is that the milky way is a spiral galaxy, sort of pancake shaped, and you see the band in the direction of the pancake. 

