# Non inertial frames of reference
So far, we have been describing classical mechanics from inertial frames. These are frames that do not experience accelerations, that is: the frame itself is thought to be in a state of constant velocity. We picture that such a frame is moving at a constant velocity with respect to the 'fixed stars'.

An inertial frame has as characteristic that the laws of Newton are valid in such a system. The question automatically arises: what does this imply for non-inertial frames? Can we use them and if so how? In this chapter, we will dig in. 
A crucial role is here for the transformation from one (coordinate) system to another. We have come across that when we discussed the Galilei Transformation. This provided, in essence, a recipe for the two observers to communicate about physics and events. By using the transformation, observers could exchange information, but also understand things form each others perspective. Or rephrased: An observer could change perspective. For instance, by moving with an object, rather than watching of from the lab frame of reference.

The Galilei Transformation, connecting two observers that move with a constant velocity with respect to each other, can be written is its most simple form as:

$$
\begin{array}{rcl}
t' &=& t\\
x' &=& x- V t\\
y' &=&y\\
z' &=& z
\end{array}
$$

It was easy to see, that if N2 applies in S then it also does so in S': $a' \equiv \frac{d^2x}{dt^2} = =\frac{d}{dt} (\frac{dx}{dt} - V ) = \frac{d^2x}{dt^2} = a$. 

We postulated $m' = m$ and found that $F = ma = m'a'$. Hence, N2 applies in S'.

What if the two observers do not move with a constant velocity with respect to each other?

## Linear accelerated frames

First, we consider two frames of reference $S$ and $S'$, where $S'$ is linearly accelerated with respect to $S$ in the $x$-direction with acceleration $A_x$. S is an inertial frame. They share a common $x$, $x'$ axis and they have both set the clock to $t=0$ when their respective origins coincide. Furthermore, we consider the case that at $t=0$, the relative velocity between the two observers is zero.

```{figure} images/LinAccFrame.png
---
name: fig:LinAccFrame.png
width: 280px
align: center
---
Frame S' accelerates with $A_x$ with respect to S.
```

Writing down the coordinate transformations for these 2 frames is easy. Consider a point P with coordinates $(x', y')$, that is according to S' point P is not moving. For S this would mean: fist move to the origin of S' and then move $x'$ in the $x$-direction and $y'$ in the $y$-direction. The origin O' is located, according to S, at $x = \frac{1}{2}A_x t^2$ as it is moving away from S at a constant acceleration. Thus, S concludes for the $x$-coordinate of point: $x = \frac{1}{2}A_x t^2 + x'$. For the $y$ component it is even more simple: $y = y'$. Thus, we can write the transformation as

$$
\begin{array}{rcl}
t' &=& t\\
x' &=& x- \frac{1}{2}A_x t^2\\
y' &=&y\\
z' &=& z
\end{array}
$$

Now we know which form Newton's laws, in particular N2, takes in $S'$.

$$
\frac{d}{dt}\vec{p}' = m' \frac{d}{dt} \vec{v}' = m \frac{d}{dt} \vec{v}'
$$

with the postulate $m'=m$ (which is correct also in relativity as we will see later).

$$
\begin{array}{rcl}
v'_{x'}\equiv \frac{d}{dt'}x' &=& \frac{d}{dt}x- A_xt\\
a'_{x'}\equiv  \frac{d}{dt'}v'_{x'} &=& \frac{d}{dt}v_x- A_x = a_x-A_x
\end{array}
$$

Now we can connect N2 in $S'$ to $S$

$$
\frac{d}{dt}\vec{p}' = m \left ( \frac{d}{dt}\vec{v}- \vec{A}\right ) = \sum \vec{F} - m\vec{A}
$$

All of a sudden the change of momentum is not given by the sum of the forces, but an extra term enters depending on the acceleration of the frame! This term has the form of a force $-m\vec{A}$ and is called *fictitious* or *inertial* force. The word *fictitious* is opposite to a "real" fundamental force such as electromagnetism, the weak and strong interaction (however, you still feel the force, it does something, the wording is a bit misleading). Luckily it turns out we can use N2 also in non-inertial frames _but_ we need to add the fictitious or inertial forces to make it work out. The force is, however, still real such that you can measure it and it has effect.

Note: all fictitious forces are proportional to the mass $m$! This has lead Einstein to consider gravity to be a fictitious force (or why they are also called *inertial* forces).

### Examples of fictitious/inertial forces

Some of the forces you experience in daily live are actually of the class "fictitious force"

- *Centrifugal force*; you get pushed outwards in a car driving a corner
- *Gravity*; you fall from a tree
- *Tidal forces*; oceans have low and high tide


A bit more unknown, but relevant for the formation of large scale currents and weather is the *Coriolis force*. Below the centrifugal and Coriolis force will be derived.

### The tides

If we start with the observation that the tides occur twice a day, twice low-tide and twice high-tide in equal time intervals. The idea that the moon attracts water to its side only, cannot be the explanation as then you only have a water "bulge" on the moon side, and while the earth rotates under the water bulge this would only give 1 tide per day, but we see 2!

The situation apparently must be as in the sketch, where we see the earth-moon system from the north pole (ignoring the inclined rotation axis). There needs to be 2 bulges of water that are static in this picture: one on the moon facing side and one on the far side of the moon due to the equal times of the tides. While the earth rotates around its axis in one day, this then gives 2 tides per day. But how can the gravity of the moon push away the water? That is very counter intuitive, but it is correct.

```{figure} images/earth-moon.png
---
name: fig:earth-moon.png
width: 380px
align: center
---
The tides: the oceans have two bulges sticking out, rather than one!.
```

The earth and moon rotate around their common CM. The CM lies at about $r_1=5,000$ km, inside the earth radius of $R=6,380$ km ($M_{earth}/M_{moon}=81$). The common CM and rotation point is called <a href="https://en.wikipedia.org/wiki/Barycenter">Barycenter</a> in astronomy. The moon accelerates the whole earth (including the water) towards the moon with gravitational pull $\vec{A}$. That is the force an observer  would feel at the earth center. On the moon facing side this force is just a bit *larger*, while on the far side the force is slightly *smaller*. Seen from the earth there is a larger force on the facing side and objects behave as if they feel an additional force that pull them towards the moon, on the far side.
<br><br>

```{figure} images/earth-moon2.png
---
name: fig:earth-moon2.png
width: 380px
align: center
---

```
<br>

To calculate the tidal force we use the equation of fictitious force $m\ddot{\vec{r}}=\sum \vec{F}-m\vec{A}$. The acceleration of the earth by the moon is given by $\vec A=-G \frac{M_{moon}}{d_0^2}\hat{d_0}$, with $d_0$ the distance moon to center of the earth, the origin of our CS. Filling this into the equation of motion for an object with mass $m$ at position $\vec{r}$ on the surface of the earth, we obtain

$$
\begin{array}{rcl}
m\ddot{\vec{r}}&=&\sum \vec{F}-m\vec{A}\\
&=&\left (m\vec{g}-G \frac{mM_{moon}}{d^2}\hat{d}  \right ) + G \frac{mM_{moon}}{d_0^2} \hat{d_0}
\end{array}
$$

The earth gravity $\vec{g}$ is here the measured acceleration (including the centrifugal acceleration). The gravitational pull of the earth and moon on the mass is the first term in the bracket and the fictitious force is the second term. The force exerted by the moon is called *tidal force* and is given by

$$
\vec{F}_{tidal} = -GmM_{moon} \left ( \frac{\hat{d}}{d^2}-\frac{\hat{d}_0}{d_0^2} \right )
$$

If we now consider a point $P$ (negative $x$-axis) on the facing side of the moon $\hat{d}$ and $\hat{d}_0$ are aligned in the same direction, with $d<d_0 \Rightarrow F_{tidal}<0$ (towards the moon, in the negative $x$-direction). For a point Q on the far side of the moon (on the positive $x$-axis), we have again $\hat{d} \| \hat{d}_0$, but $d>d_0 \Rightarrow F_{tidal}>0$ (away from the moon). This explains that the moon creates two bulges rather than one. 

In astronomy these tidal forces are very important when studying rotating two bodies systems. Do not forget that each body exerts the tidal force on the other body! Depending on the relative mass of the two bodies and their distance, there will be a range where the tidal force is as strong as the gravitational forces holding the smaller of the bodies together. This limit is called the <a href="https://en.wikipedia.org/wiki/Roche_limit">Roche limit</a>. If the tidal forces are larger than the gravitational force holding the smaller body together it will be ripped apart. This holds for moons orbiting a planet, but also for binary star systems. Inside the Roche limit of a planet/star there cannot be another orbiting star, but then rings are formed (from debris of the disintegrated body).

Note: If you obtain information on the origin of the tides from the internet or a popular program, these might be plainly wrong or just not right quite some time. We did not discuss the centrifugal force at all? Why? Typically popular explanations mix in this force in an inappropriate way (or another).

The centrifugal force has shaped the surface of the earth to be not a sphere but a bit ellipsoidal. When the earth was fully fluid this reshaping was easy and then it cooled down. The rotating earth with the water is therefore in equilibrium. The surface of the water is an equipotential line of the combined gravitational field of the earth and the centrifugal potential. 
	
### Tidal locking and the dark side of the moon


```{figure} images/Dark_Side_of_the_Moon.png
---
name: fig:Dark_Side_of_the_Moon.png
width: 240px
align: center
---
The cover of the LP "dark side of the moon", Pink Floyd. Copyright pending.
```

From the earth we always see the same side of the moon. The moon rotates such that it revolves around itself in one month, the same time it needs to rotate around the earth, therefore from the earth we only see the same side. This is not happenstance!

In fact this happens due to tidal forces inducing small deformations on the other body (considering the bodies solid only, with no liquid now). On these deformations the gravitational pull acts now as a torque, reducing the rotation speed of the other body until it is in *tidal locking*. Over millions of years, the tidal forces first, bring one body into locking then the other. 

The total angular momentum of the two body system (earth-moon) must, of course, be conserved! The angular momentum a body looses is transferred to its orbital angular momentum. Sometimes this therefore referred to as *spin-orbit locking*.

NB: note the similar wording in many Germanic languages: moon - month (eng.), maan - maand (dutch), Mond - Monat (deu.), m&aring;ne - m&aring;nad (swe.) 

### Gravity as a fictitious force

As the form of a fictitious force is $-m\vec{A}$ and the force in a uniform gravitational field is $-m\vec{g}$ it is not so strange to think in this direction.

Einstein came up with the following Gedankenexperiment: If you are in a closed box elevator, you cannot distinguish if the elevator is in a uniform gravitational field of strength $\vec{g}$ or if it is accelerated with $\vec{g}$ (by some alien pulling it with a starship). Stated differently, a free-falling observer in a box cannot decide between acceleration or gravity. This directly makes it clear that heavy mass (measured with a balance; occurring in $F_g=-\frac{mM}{r^2}$) and inertial mass (measured with a scale; occurring in $\vec{F}=ma$) are the same on a conceptual level. This is know as the <a href="https://en.wikipedia.org/wiki/Equivalence_principle">*weak equivalence principle*</a> which guided Einstein during the development of the general theory of relativity. (Gravitational) acceleration is then a consequence of the curvature of spacetime.

## Rotating frames


```{figure} images/rotframe.png
---
name: fig:rotframe.png
width: 240px
align: center
---
A rotating frame of reference.
```


We place ourself in a frame of reference rotating with constant angular speed $\dot{\phi}=\omega =const$ around the $z$-axis. We will find the *centrifugal* and *Coriolis* force appearing as fictitious forces by inspecting N2 in a rotating frame.

```{figure} images/rotframe2.png
---
name: fig:rotframe2.png
width: 240px
align: center
---
Top view of the rotating frame of reference.
```


We start out by writing down the coordinate transformation, then the velocity and acceleration to find the relation for N2 between the two frames of reference. The transformation between the inertial frame $S$ and the rotating frame $S'$ in terms of coordinates is (with angle $\phi (t)$)

$$
\begin{array}{lcr}
x &=& \cos\phi \,x' - \sin\phi \,y'\\
y &=& \sin\phi \,x' + \cos\phi \,y'\\
\end{array}
$$

Now we need to take the time derivate of these equations to find the velocities (with product and chain rule)

$$
\begin{array}{lcl}
\dot{x} &=& -\sin\phi\, \dot{\phi}x' +\cos\phi\, \dot{x}' - \cos\phi\, \dot{\phi}y' -\sin\phi\, \dot{y}' \quad (*)\\
\dot{y} &=& \cos\phi\, \dot{\phi}x' +\sin\phi\, \dot{x}' - \sin\phi\, \dot{\phi}y' +\cos\phi\, \dot{y}'\\
\end{array}
$$

As these equations must hold for any angle $\phi$ we choose $\phi=0$.

We are interested in the dynamics, so the fact that for a given $\phi$ the two frames are rotated with respect to each other, doesn't matter. A 'one time' rotation over a given angle has no consequences for velocity or acceleration.

Thus we can write:

$$
\begin{array}{lcr}
\dot{x} &=& \dot{x}' - \dot{\phi}y' =\dot{x}' - \omega y'\\
\dot{y} &=& \dot{y}'+\dot{\phi}x' = \dot{y}'+\omega x'\\
\end{array}
$$

with the substitution $\omega=\dot{\phi}$. We see here the cross product

$$
\vec{\omega}\times\vec{r}_{S'} = 
\left ( \begin{array}{c} 0 \\ 0\\ \omega\end{array}\right ) \times
\left ( \begin{array}{c} x' \\ y'\\ 0\end{array}\right ) =
\left ( \begin{array}{c} -\omega x' \\ +\omega y'\\ 0\end{array}\right )
$$

Therefore we find for the connection of the velocities

$$
\vec{v}_S = \vec{v}_{S'}+\vec{\omega}\times\vec{r}_{S'}
$$

To get the acceleration we need again to calculate the time derivative of the equations $(*)$, remember that $\ddot{\phi} =0$ (by our assumption $\omega =const$), and then we set $\phi=0$. We then obtain (after quite some work)

$$
\begin{array}{lcr}
\ddot{x} &=& \ddot{x}'-2\omega \dot{y}' -\omega^2 x'\\
\ddot{y} &=& \ddot{y}'+2\omega \dot{x}' -\omega^2 y'\\
\end{array}
$$

The last term can be identified by the double cross product

$$
\vec{\omega}\times (\vec{\omega}\times\vec{r}_{S'}) = 
\left ( \begin{array}{c} 0 \\ 0\\ \omega\end{array}\right ) \times
\left ( \begin{array}{c} -\omega y' \\ +\omega x'\\ 0\end{array}\right ) =
\left ( \begin{array}{c} -\omega^2 x' \\ -\omega^2 y'\\ 0\end{array}\right )
$$

Summarizing we obtain for the acceleration

$$
\vec{a}_{S} = \vec{a}_{S'} + 2 \vec{\omega}\times\vec{v}_{S'} + \vec{\omega}\times (\vec{\omega}\times\vec{r}_{S'})
$$

Or in terms of force and rearranging

$$
m\vec{a}' = \vec{F} - 2m \vec{\omega}\times\vec{v}' - m\vec{\omega}\times(\vec{\omega}\times\vec{r}') \quad (**)
$$

The last extra term to the acceleration is the *centrifugal force* term. It is directed along the position vector $\vec{r}$ away from the rotation axis. The first additional term is the *Coriolis force* that can only occur if an object has velocity $v'\neq 0$ in the rotating frame (see for the examples below). 

Note: the "-" in-front of the forces can easily be converted into a "+" by changing the order of the cross product! Be careful here. $m\vec{a}' = \vec{F} + 2m \vec{v}'\times\vec{\omega} + m\vec{\omega}\times(\vec{r}'\times\vec{\omega})$ is also correct, different books or some random internet site might use different notation.


You can visualize the necessity of such a fictitious force for example as follows. Imaging an alien is watching from space a train traveling straight north from Delft on the surface of the Earth. As the train moves north, the earth rotates a bit, so in effect for the alien the train not only moves up (north) but also a bit to the right (east), while the train in the rotating frame of reference of a passenger thinks to move only north but at the same time the right rail on the track gets worn out faster!

---

If the frame is also accelerating ($\omega \neq const.$) an additional fictitious force is appearing called the *Euler force*. It has the form $-m\dot{\vec{\omega}} \times \vec{r}$.

---

You can derive the above result more compactly in vector form if you apply the <a href="https://en.wikipedia.org/wiki/Transport_theorem">transport theorem</a> from vector calculus twice. The theorem states that the change of a vector $u$ evaluated in a frame of reference rotating with constant speed $\vec{\omega}$ is given by

$$
\left [ \frac{d}{dt} \vec{u}\right ]_S = \left [ \frac{d}{dt} \vec{u}\right ]_{S'}+\vec{\omega} \times \vec{u}_{S'}
$$

You can see that this relation holds by considering how a unit vector transforms in a rotating CS. From [the rigid body](rigid_body.md#angular-velocity-and-acceleration) we know $\vec{v}=\vec{\omega}\times \vec{r}$. Now we apply this to the unit vectors $\hat{x},\hat{y},\hat{z}$ which gives us 

$$
\frac{d\hat{x}}{dt} = \vec{\omega} \times \hat{x},
$$ 

etc. for the other unit vectors. Applying this to a general vector $\vec{u}=u_x \hat{x} + u_y \hat{y} + u_z \hat{z}$ we find with the product rule 

$$
\begin{array}{rcl}
\frac{d\vec{u}}{dt} &=& \frac{\partial u_x}{\partial t}\hat{x} + u_x \frac{d\hat{x}}{dt} + 
\frac{\partial u_y}{\partial t}\hat{y} + u_y \frac{d\hat{y}}{dt} +
\frac{\partial u_z}{\partial t}\hat{z} + u_z \frac{d\hat{z}}{dt} \\
&=& \left ( \frac{\partial u_x}{\partial t}\hat{x} + \frac{\partial u_y}{\partial t}\hat{y} + \frac{\partial u_z}{\partial t}\hat{z} \right )
+ \left ( u_x \frac{d\hat{x}}{dt} + u_y \frac{d\hat{y}}{dt} + u_z \frac{d\hat{z}}{dt} \right )\\
&=& \left [ \frac{d\vec{u}}{dt} \right ]_{S'} + \vec{\omega} \times \vec{u}
\end{array}
$$

The first term is the derivative in the rotating CS (which is now also defined by this equation) and the last term is given by the change of the unit vectors.

Applied to our problem of the acceleration this gives the same equation as above of course

$$
\begin{array}{lcr}
\left [ \frac{d^2}{dt^2} \vec{r}\right ]_S &=& \left [ \frac{d}{dt} \right ]_S \left [ \frac{d}{dt} \vec{r}\right ]_S= \left [ \frac{d}{dt} \right ]_S (\vec{v}_{S'}+\vec{\omega}\times \vec{r}_{S'})\\
&=& \vec{a}_{S'} +  \vec{\omega}\times\vec{v}_{S'} + \vec{\omega}\times (\vec{v}_{S'}+\vec{\omega}\times\vec{r}_{S'})
\end{array}
$$

### Foucault's pendulum

```{figure} images/Pendule_de_Foucault.JPG
---
name: fig:Pendule_de_Foucault.JPG
width: 340px
align: center
---
The pendulum of Foucault in the Panthéon, Paris. From [Wikimedia Commons](https://commons.wikimedia.org/wiki/File:Panth%C3%A9on_Pendule_de_Foucault2.JPG) by Rémih, licensed under CC-BY-SA 3.0.
```

The pendulum of Foucault is just a pendulum really. It is a good experiment to demonstrate the rotation of the earth. In order to derive the equation of motion and work out the orbit of the pendulum, we start with a pendulum under the influence of gravity and apply the rotating frame of reference transformation derived above. 



```{figure} images/CS_Foucault.png
---
name: fig:CS_Foucault.png
width: 240px
align: center
---
Coordinate system for Foucault's pendulum for a pendulum in Delft.
```

The force on the pendulum (length $l$) is given by

$$
\vec{F}_T = \frac{T}{l}x'\hat{x} + \frac{T}{l}y'\hat{y} + (\frac{T}{l}z'-mg)\hat{z}
$$

with $T$ the tension force in the pendulum. Writing down the equation of motion in the frame of the rotation earth

$$
\vec{F}_T = m\ddot{\vec{r}}' +2m \vec{\omega} \times \dot{\vec{r}}'
$$

The centrifugal term of equation $(**)$ disappeared. Why is it not needed? Where did it go? Try to reason it before looking at the answer.

```{admonition} Answer
:class: tip, dropdown

Note: The centrifugal term of equation $(**)$ is indeed there, but it is integrated into the effective gravitational term $m\vec{g}$ already of the force on the pendulum, where $\vec{g}$ is the *observed* free-fall acceleration for that latitude. The observed $\vec{g}$ includes the reduction of $\vec{g}_0$ (from the mass of the earth) by the outward directed centrifugal force.
```
	
Let's first work out the cross product of the Coriolis force. Looking at the coordinate system in the figure we can write down the rotation vector $\vec{\omega}$ in the CS located in Delft ($\hat{x},\hat{y},\hat{z}$), $\vec{\omega}     \perp \hat{y}$ with $\hat{y}$ in the screen and cross it with the velocity

$$
\vec{\omega}\times \dot{\vec{r}}' = 
\left ( \begin{array}{c}
-\omega \cos\varphi \\0\\ \omega \sin\varphi
\end{array} \right ) \times
\left ( \begin{array}{c}
\dot{x}' \\ \dot{y}' \\ \dot{z}'
\end{array} \right ) =
\left ( \begin{array}{c}
-\dot{y}'\omega \sin\varphi \\ -(-\dot{z}' \omega \cos\varphi - \dot{x}' \omega \sin\varphi) \\ -\dot{y}\omega \cos\varphi
\end{array} \right ) 
$$

Here the angle $\varphi$ is the latitude on the earth (Delft $\varphi \sim 52^o$). Now we can write down the equations of motion for the 3 components

$$
\begin{array}{rcl}
\frac {T}{ml}x' &=& \ddot{x}'-2\omega\sin\varphi\, \dot{y}' \\
\frac {T}{ml}y' &=& \ddot{y}'+2\omega\sin\varphi\, \dot{x}' + 2\omega\cos\varphi\, \dot{z}' \\
\frac {T}{ml}z'-g &=& \ddot{z}'-2\omega\cos\varphi\, \dot{y}'
\end{array}
$$

If we use again the small amplitude approximation of the pendulum, we can use $z'=l$ as the height stays about constant and thus $\ddot{z}'= \dot{z}'\approx 0$ with $T=-mg$. We only need to look at the $x,y$ plane now. With constants $\alpha\equiv g/l$ with unit [1/s$^2$] and $\beta\equiv \omega \sin\varphi$ with unit [1/s] we have

$$
\begin{array}{rcl}
\ddot{x}'-2\beta \dot{y}' +\alpha x' &=&0 \\
\ddot{y}'+2\beta \dot{x}' +\alpha y' &=&0
\end{array}
$$

A solution to this coupled differential equation is 

$$
\begin{array}{rcr}
x'(t) &=& A \cos(\beta t) \cos (\Omega t)\\
y'(t) &=& -A \sin(\beta t) \cos (\Omega t)\\
\end{array}
$$

with $\Omega^2 \equiv \alpha+\beta^2$ with $\Omega$ unit [1/s]. Note: you could solve the coupled differential equation by introduction $\eta\equiv x+iy$ to obtain one complex equation which can be solved directly with a complex exponential.

Finally, to analyze the motion of oscillation we make a coordinate transformation to polar coordinates $r',\theta'$ in the CS fixed to Delft

$$
\begin{array}{rcll}
r'(t) &=& \sqrt{x'^{2}+y'^2} &= A \cos (\Omega t)\\
\theta'(t) &=& \arctan(y'/x') &=-\beta t
\end{array}
$$

The motion in radial direction is an oscillation with frequency $\Omega = \sqrt{g/l + \omega^2 \sin^2\varphi}$. With $\omega=0$ it must reduce to the [pendulum](pendulum.md#equation-of-motion) frequency for small angles or the [harmonic oscillator](harmonic_oscillator.md#undamped-harmonic-oscillator) that we treated before without rotation. Check! 

The plane of oscillation is rotating linearly as function of time as the angle $\theta' (t)=-\beta t$. The speed of rotation depends on $\beta\equiv \omega \sin\varphi$ on the latitude $\varphi$. To get a feeling for the rotation, have a look at the periods $T$ of rotation of the pendulum plane

$$
\frac{2\pi}{T} = \omega \sin\phi = \frac{2\pi}{d}\sin\varphi \Rightarrow T=\frac{d}{\sin\varphi}
$$

with earth's rotation speed $\omega=2\pi /d$ and $d=60\cdot 60\cdot 24$ the time of one day in seconds. For $\varphi=52^o$ we obtain a rotation of the plane of oscillation of $11^o$ per hour. At the poles the rotation is the shortest $T=d$ and on the equator "the longest" as there the plane stays constant.

Click <a href="https://www.youtube.com/watch?v=Ax6Pij-CI6c">animation of the Foucault pendulum</a>" from a fixed and rotating frame of reference.

And click <a href="https://www.youtube.com/watch?v=aMxLVDuf4VY">a bit of explanation</a> about the rotation of the pendulum.

### Euler's equations 

*This part goes beyond the content of our first year course and is not part of the examination.*

Up to now we implicitly always assigned a rotation axis to the [moment of inertia](rigid_body.md#moment-of-inertia). In our formalism $I=\int_M r^2 dm$, $r$ was the distance to the rotation axis $\vec{\omega}$ where it was necessary that $\vec{r}\perp \vec{\omega}$. 
To generalize the description to rotations around arbitrary axis we first need to extend the moment of inertia.

Starting from 

$$
\vec{L}=\sum m_s r_s \times (\vec{\omega} \times \vec{r}_s)
$$

we can write the total angular momentum as $\vec{L}\equiv {\bf I} \vec{\omega}=\sum_i I_{ij}\omega_i$ with 

$$
I_{ij} \equiv \sum_s m_s (r^2 \delta_{ij}-r_ir_j),\quad i,j=1,2,3 (=x,y,z)
$$

with $r^2 = r_1^2 +r_2^2 +r_3^2 = x^2 +y^2 +z^2$ and $\delta_{ij}$ the <a href="https://en.wikipedia.org/wiki/Kronecker_delta">Kronecker delta</a>".
From the construction it is clear that $I_{ij}$ has 9 components but the off-diagonal components are symmetric ($I_{xy}=I_{yx}, I_{xz}=I_{zx}, I_{yz}=I_{zy}$), and only 6 unique components remain. The first component, for example, is $I_{xx}=\sum_s m_s(y^2+z^2)$. That is consistent with our earlier definition as for a rotation around the $x$-axis the distance to this axis is given by $\sqrt{y^2+z^2}$.

As the moment of inertia ${\bf I}$ is a real-valued symmetric tensor it can be brought to *principal axis*. You will learn this in the class *Linear Algebra* under the term <a href="https://en.wikipedia.org/wiki/Eigendecomposition_of_a_matrix">eigen decomposition of a matrix</a>. In plain words this means that there exists an orthonormal coordinates system (given by the principal axes) where the tensor only has diagonal elements ($I_{i}=I_{ii}=I_{ij}\delta_{ij}$) and that you can find this coordinate system by rotation. Each of the diagonal elements then corresponds to the moment of rotation around that axis. We will make use of this property shortly.

We now will study rotations not in the lab frame but in a corotating frame (just as we did with the CM system for collisions). To transfer "N2" of rotation $\vec{\Gamma} = \dot{\vec{L}}$  to a rotating frame $S'$, we make use of the transport theorem introduced above. 

$$
\vec{\Gamma}=\frac{d\vec{L}}{dt} = \left [ \frac{d\vec{L}}{dt}\right ]_{S'} + 
\vec{\omega} \times \vec{L}
$$

Substituting $\vec{L}= {\bf I} \vec{\omega}$

$$
\vec{\Gamma}={\bf I} \dot{\vec{\omega}} + \vec{\omega}\times ({\bf I} \vec{\omega})
$$

If we now bring the inertia tensor on principal axis ($I_{ij}\delta_{ij}\equiv I_i$) the above equation can be evaluated in this coordinate frame

$$
\vec{\Gamma} = 
\left ( 
\begin{array}{c}
I_1 \dot{\omega}_1 \\
I_2 \dot{\omega}_2 \\
I_3 \dot{\omega}_3
\end{array}
\right ) +
\left ( 
\begin{array}{c}
{\omega}_1 \\
{\omega}_2 \\
{\omega}_3
\end{array}
\right ) \times
\left ( 
\begin{array}{c}
I_1 \omega_1 \\
I_2 \omega_2 \\
I_3 \omega_3
\end{array}
\right )
$$

If we work out the above and assume no external torque we arrive at the *Euler equations for a rotating object*, they describe the time evolution of the rotations of a 3D object.

$$
\begin{array}{rcl}
I_1 \dot{\omega}_1 &=& \omega_2 \omega_3 (I_2-I_3)\\
I_2 \dot{\omega}_2 &=& \omega_1 \omega_3 (I_3-I_1)\\
I_3 \dot{\omega}_3 &=& \omega_1 \omega_2 (I_1-I_2)\\
\end{array}
$$

You see that the rotations around one axis can be coupled to the rotations around others axes depending on the relative size of the principal moments of inertia. 

In general it is now also unclear if a rotation can be stable or not. I.e. does a rotation around an axis change over time while there is no external torque? From the conservation of angular momentum $\dot{\vec{L}}=0$ we would expect this of course, but let's have a closer look below.

### Dzhanibekov effect 

For an object with three different principal moments of inertia $I_1 < I_2 < I_3$ (without loss of generality) it turns out that rotation around the second (intermediate) axis is unstable. This is called the *Dzhanibekov effect* or *intermediate axis theorem*. You can see a <a href="https://www.youtube.com/watch?v=1x5UiwEEvpQ">cool example here</a> here.

We can analyze this behavior with the help of the Euler equations.

We start by investigating a rotation around axis 1, $\omega_1$. Will rotations around other axes be initiated by the coupling of the equations? and if so, how will they evolve? Initially we have $\omega_1 \gg \omega_2, \omega_3$ and start with the first Euler equation

$$
\dot{\omega}_1 = \omega_2 \omega_3 \frac{I_2-I_3}{I_1} = 0
$$

or in other words, $\omega_1=const.$. If we now take the time derivative of the second Euler equation, and substitute the above and the third equation, we arrive at

$$
\ddot{\omega}_2 = \frac{I_3-I_2}{I_1}(\dot{\omega}_1{\omega}_3 + {\omega}_1\dot{\omega}_3) =
\frac{I_3-I_2}{I_1}\frac{I_1-I_2}{I_3} \omega_1^2 \omega_2
$$

The first term $\frac{I_3-I_2}{I_1}>0$ while $\frac{I_1-I_2}{I_3}<0$ and $\omega_1^2=const.$ we can rewrite the equation as

$$
\ddot{\omega}_2  + c\omega_2 =0
$$

with some constant $c>0$. This is the equation of the [undamped harmonic oscillator](harmonic_oscillator.md#undamped-harmonic-oscillator) with solution $\omega_2(t)\sim \cos(t)$. In terms of stability, the amplitude of the rotation $\omega_2$ is bound, i.e. it does not grow over time.  We can work out the same conclusion for $\omega_3$. Therefore the rotation around $\omega_1$ is stable.

If we follow the same steps for an initial rotation around the intermediate axis 2 we find $\dot{\omega}_2=0$ and then again take the time derivative of the first Euler equation we find

$$
\ddot{\omega}_1 = 
\frac{I_2-I_3}{I_1}\frac{I_1-I_2}{I_3} \omega_2^2 \omega_1
$$

with $\frac{I_2-I_3}{I_1}<0$ and $\frac{I_1-I_2}{I_3} <0$, therefore the differential equation for $\omega_1$ is

$$
\ddot{\omega}_1 - k\omega_1 =0
$$

with some constant $k>0$. The seemingly small difference is a minus sign instead of a plus sign compare to earlier. However, this causes the solution to change from a sine/cosine to a real exponential $\omega_1(t)\sim e^{\sqrt{k}t}+e^{-\sqrt{k}t}$. This means that very quickly the rotation amplitude around $\omega_1$ will increase. The same behavior is observed for $\omega_2$. This causes the object to "flip over" very quickly and it not only rotates around $\omega_2$ anymore. 


![Intermediate axis theorem](images/tennis.gif)
<!-- gif is missing from files -->

The rotation around $\omega_2$ is unstable. If you seen the [movie](https://www.youtube.com/watch?v=1x5UiwEEvpQ), you now also understand why the rotating nut is flipping from its initial rotation so quickly. In the same manner you find that rotation around $\omega_3$ is stable, only the intermediate axis has this "problem".

You can try this at home with a tennis racket.


## Worked Example

A charged particle of mass $m$ and charge $q$ is moving in a static uniform magnetic field $\vec{B}=(0,0,B_z)$. On this particle the <a href="https://en.wikipedia.org/wiki/Lorentz_force">Lorentz force</a> is acting $\vec{F}_L = q\vec{E}+q\vec{v}\times \vec{B}$. As the force acts perpendicular to $\vec{v}$ and $\vec{B}$ the magnitude of the velocity cannot change, but only its direction. The particle will move in a circle, or a spiral along the $z$-direction if the particle has an initial velocity. We can see this directly from the equation of motion

$$
\begin{array}{rcl}
m \dot{\vec{v}} &=& q\vec{v}\times \vec{B}\\
\vec{v} \cdot m \dot{\vec{v}} &=& \vec{v} \cdot (q\vec{v}\times \vec{B}=0\\
&\Rightarrow & \frac{1}{2} m\frac{d}{dt}\vec{v}^2=0 \Rightarrow | \vec{v} |=const.
\end{array}
$$

If we define the angular frequency of motion with $\vec{\omega}\equiv \frac{q}{m} \vec{B}$ with  $\vec{B}=(0,0,B_z)$ we can evaluate the cross product to find 

$$
\begin{array}{rcr}
\dot{v}_x &=& \omega v_y \\
\dot{v}_y &=& -\omega v_x
\end{array}
$$

The solution to this couple differential equation is 

$$
\begin{array}{rcl}
v_x &=& v_0 \sin (\omega t)\\
v_y &=& v_0 \cos (\omega t)\\
\end{array}
$$

Integrating this from velocity to position, gives a circle.

Now we choose to sit in the frame $S'$ of the rotating particle. The frame is rotating and potentially moving with constant initial velocity $v_z$. As the particle is standing still $v'=0$ the magnetic part of the Lorentz force $\vec{v}\times \vec{B}=0$! Going back to equation $(**)$

$$
m\vec{a}' = \vec{F} - 2m \vec{\omega}\times\vec{v}' - m\vec{\omega}\times(\vec{\omega}\times\vec{r}')
$$

We have $m\vec{a}'=0$ in $S'$ and $\vec{\omega}\times\vec{v}'=0$ as $\vec{v}'=0$, the centrifugal force is $m\omega^2 r' \hat{r}' \neq 0$ ($r'$ the distance of the particle to the rotation axis and $\hat{r}'$ the unit vector pointing towards the center) and equals the electric part of the Lorentz force $0=F_L -  m\vec{\omega}\times(\vec{\omega}\times\vec{r}')$. The observer $S'$ sees an electric field of strength $\vec{E}=\frac{m}{q}\omega^2 r'\hat{r}'$! The electric field is not constant in space but radially pointing inwards to the rotation axis. The strength depends on the $B$-field by $\omega$.

More importantly, in the rotating frame there is no magnetic field to cause the motion, but an electric field! This example shows that electric and magnetic fields are in fact two sides of the same thing. If you interpret it as magnetic or electric depends on the frame! The underlying physics is electromagnetic.

## Examples

1. Observe the Coriolis effect for the flow around a low pressure area in this video from <a href="https://www.nationalgeographic.org/encyclopedia/coriolis-effect/#what-is-the-coriolis-effect">National Geography</a>.

1. <a href="https://de.wikipedia.org/wiki/Teufelsrad_(Fahrgesch%C3%A4ft)">Teufelsrad auf dem Oktoberfest</a>

1. The article entry on <a href="https://en.wikipedia.org/wiki/Fictitious_force">wikipedia</a> about fictitious forces is nice.


## Exercises

```{exercise-start}
:label: 14.1
```
You are sitting in the passengers seat of a fast car. The driver is in a hurry and as soon as the traffic light turns green pushes the gas. The car accelerates in 4 seconds to 100km/h (with a constant acceleration).
Compute the strength of the force you feel pushing you into your seat.

```{exercise-end}
```

```{exercise-start}
:label: 14.2
```
At the yearly fair you can enter a cabin that is moving up and down in sinusoidal way. The claim is, that you will virtually feel weightless when the cabin is coming down and that you can barely stand straight when it is moving up.
Curious as you are, you buy a ticket and get in. Inside the cabin there are scales on the floor, allowing you to watch you weight during the motion.

On the flyer it said: the amplitude of the motion is 2m and the period 5s. 

Inside the cabin, you indeed feel your weight changing, but almost weightless ...? The scale however does show that your weight has dropped to almost zero. But you doubt it!
Calculate the minimum and maximum weight the scale you are standing should give.

```{exercise-end}
```

```{exercise-start}
:label: 14.3
```
At the same fair you spot a huge merry-go-round and decide to take a ride. The claim is, that the swing you will be sitting on, will make an angle of $45^\circ$ with the vertical.

```{figure} images/MerryGo.png
---
name: fig:MerryGo.png
width: 380px
align: center
---
Merry-go-round.
```

However, before buying the ticket, you want to make sure that the claim is correct.
You timed the rotations and noted that it takes only 5s to complete one revolution. You estimate the arm of the merry-go-round to be $a=4m$ and you estimate that the length of the cable to which the swings are attached is also $L=4m$.

Compute the angle the swings make, based on your estimates. If the angle is indeed the claimed $45^\circ$ or more, you will take a ride. What will you do?
```{exercise-end}
```

```{exercise-start}
:label: 14.4
```

A beat of mass $m$ can move over a straight rod. The rod is thin and the beat can be treated as a point particle. The left side of the rod is fixed to the origin, the other side coincides with the positive $x$-axis and stretches to infinity.

The rod in brought into rotation around the vertical axis at a constant angular velocity, $\omega$. The beat is initially kept at position $x_0 \gt 0$. From $t=0$ onwards, the beat is allowed to slid over the rod. When moving, it will experience friction: $F_f = -bv$ with $b \gt 0$ and $v$ the velocity of the beat in a frame of reference moving with the rod.

Question: will the beat reach infinity and if so with a finite or infinite velocity?

```{exercise-end}
```

## Answers ##

```{solution-start} 14.1
:class: dropdown
```
acceleration of car: $a = \frac{100/3.6}{4} = 6.9 m/s^2$
fictitious force: $F = -ma \approx -520 N$ (assuming a mass of 75kg)

```{solution-end}
```

```{solution-start} 14.2
:class: dropdown
```
motion of the cabin: $z(t) = A \sin \omega t$ with $A=2m$ and $\omega = 2\pi f = \frac{2\pi}{T} = 1.26 rad/s$
acceleration of cabin: $a = \ddot{z} = - A \omega^2 \sin \omega t$

Thus, the fictitious force is $F = -ma = A m\omega^2 \sin \omega t$.

The scale will balance gravity and the fictitious force:

$$ W = mg + ma = mg \left ( 1 + \frac{A \omega^2}{g} \sin \omega t \right )$$

Thus, minimum weight: a factor of  $1 - \frac{A \omega^2}{g} = 0.68$ of your weight and maximum: a factor of  $1 + \frac{A \omega^2}{g} = 1.32$

Not even close to weightless: you have been ripped off.

```{solution-end}
```

```{solution-start} 14.3
:class: dropdown
```

We analyse the forces on the swing from a rotating frame of reference. In this frame, the swing is motionless. Thus the sum of forces must be zero.

```{figure} images/MerryGoSol.png
---
name: fig:MerryGoSol.png
width: 380px
align: center
---
Forces on the swing.
```

$$\begin{split} 
0 &= F_t \cos\theta - mg \\
0 &= -F_t \sin \theta + m\omega^2 \left ( a + L \sin \theta \right )
\end{split} $$

Eliminate $F_t$:

$$\frac{\sin \theta}{\cos \theta} = \frac{a\omega^2}{g} \left ( 1 + \frac{L}{a} \sin \theta \right ) $$

Solve for $theta$ (numerically or graphically) and find: $theta= 48.4^\circ$. So you swing at more than $45^\circ$ with the vertical and you decide to buy a ticket.

```{solution-end}
```


```{solution-start} 14.4
:class: dropdown
```

Consider this from a frame rotating with the rod. Here the rod is not moving and we will take it a sour $x$-axis.

The beat experiences 2 forces: $F_c = m\omega^2 x$ and $F_f = -b \dot{x}$. Thus the equation of motion reads as:

$$m\ddot{x} = -b \dot{x} + m\omega^2 x$$

Global consideration: if the beat does not reach infinity, it will have to come to a hold at some position $x_h$. But that means that its velocity is then zero and thus the friction force is zero. However, the centrifugal force is non-zero and thus the beat will accelerate and have a positive velocity. Hence $x_h$ can not be a point of zero velocity. Conclusion: the beat will keep moving and eventually reach infinity.

Mathematical analysis:

$$m\ddot{x} + b \dot{x} - m\omega^2 x = 0$$

Try $x = A e^\lambda t$:

$$\lambda^2 + \frac{b}{m}\lambda - \omega^2 = 0 \Rightarrow \lambda_\pm = \frac{-\frac{b}{m} \pm \sqrt{\frac{b^2}{m^2} + 4 \omega^2}}{2} $$

General solution:

$$x(t) = A e^{\lambda_+ t} + B e^{\lambda_- t}$$

with initial conditions: 

$$
t=0 \left \{ 
\begin{split}
v&=0 \rightarrow A \lambda_+ + B \lambda_- = 0 \\
x&=x_0 \rightarrow A + B = x_0
\end{split}
\right .
$$

From these last equation, we can solve $x(t)$. However, we don't need to. We can notice that $\lambda_+ \gt 0$ and $\lambda_- \lt 0$. Thus in the long run $x(t) \approx A e^{\lambda_+ t}$. Consequently, $v(t) \approx A\lambda_+ e^{\lambda_+ t}$

Conclusion: the bead will go to infinity with an ever increasing velocity that also goes to an infinite value.


```{solution-end}
```
